Module own

Module own 

Own namespace of the module.

Structs

AdminApiKey
Represents an Admin API Key.
AdminApiKeyOwner
Represents the owner of an Admin API Key (User or Service Account).
ApiKeyList
Response containing a list of Admin API Keys.
Invite
Represents an invitation to join an organization.
InviteListResponse
Response containing a list of organization invites.
InviteProject
Represents project membership granted upon invite acceptance.
Project
Represents an organization project.
ProjectApiKey
Represents an API key associated with a project.
ProjectApiKeyListResponse
Response containing a list of project API keys.
ProjectApiKeyOwner
Represents the owner of a Project API Key (either a User or Service Account).
ProjectListResponse
Response containing a list of organization projects.
ProjectRateLimit
Represents rate limit configuration for a specific model within a project.
ProjectRateLimitListResponse
Response containing a list of project rate limits.
ProjectServiceAccount
Represents a service account within a project.
ProjectServiceAccountApiKey
Represents the API key generated for a new service account (only present on creation).
ProjectServiceAccountCreateResponse
Response object returned when creating a project service account.
ProjectServiceAccountListResponse
Response containing a list of project service accounts.
ProjectUser
Represents a user’s membership within a specific project.
ProjectUserListResponse
Response containing a list of users within a project.
User
Represents a user within an organization.
UserListResponse
Response containing a list of organization users.