pub struct ImageFileContent {
pub file_id: String,
pub detail: Option<String>,
}Expand description
Contains the file ID and detail level for an image file content part.
Used By
MessageContentImageFileObject
Fields
file_id: StringThe File ID of the image in the message content.
detail: Option<String>Specifies the detail level of the image if specified by the user (auto, low, high).