pub struct RequiredAction {
pub type: String,
pub submit_tool_outputs: SubmitToolOutputs,
}Expand description
Details on the action required to continue the run (currently only tool outputs).
Used By
RunObject
Fields
type: StringFor now, this is always submit_tool_outputs.
submit_tool_outputs: SubmitToolOutputsDetails on the tool outputs needed for this run to continue.