pub struct ChatCompletionLogprobsContent {
pub token: String,
pub logprob: f32,
pub top_logprobs: Vec<ChatCompletionLogprobsTopLogprob>,
}Expand description
Represents log probability information for a single token in the completion.
Used By
ChatCompletionLogprobs
Fields
token: StringThe token.
logprob: f32The log probability of the token.
top_logprobs: Vec<ChatCompletionLogprobsTopLogprob>A list of the most likely tokens and their log probabilities.