pub struct CreateCompletionResponse {
pub id: String,
pub choices: Vec<CompletionChoice>,
pub created: i64,
pub model: String,
pub system_fingerprint: Option<String>,
pub object: String,
pub usage: Option<CompletionUsage>,
}Expand description
Represents a completion response from the legacy API. Note : both the streamed and non-streamed response objects share the same shape.
Used By
/completions(POST)
Fields
id: StringA unique identifier for the completion.
choices: Vec<CompletionChoice>The list of completion choices the model generated for the input prompt.
created: i64The Unix timestamp (in seconds) of when the completion was created.
model: StringThe model used for completion.
system_fingerprint: Option<String>This fingerprint represents the backend configuration that the model runs with.
object: StringThe object type, which is always “text_completion”.
usage: Option<CompletionUsage>Usage statistics for the completion request.