Exposed namespace of the module.
Structs
- Admin
ApiKey - Represents an Admin API Key.
- Admin
ApiKey Owner - Represents the owner of an Admin API Key (User or Service Account).
- ApiKey
List - Response containing a list of Admin API Keys.
- Invite
- Represents an invitation to join an organization.
- Invite
List Response - Response containing a list of organization invites.
- Invite
Project - Represents project membership granted upon invite acceptance.
- Project
- Represents an organization project.
- Project
ApiKey - Represents an API key associated with a project.
- Project
ApiKey List Response - Response containing a list of project API keys.
- Project
ApiKey Owner - Represents the owner of a Project API Key (either a User or Service Account).
- Project
List Response - Response containing a list of organization projects.
- Project
Rate Limit - Represents rate limit configuration for a specific model within a project.
- Project
Rate Limit List Response - Response containing a list of project rate limits.
- Project
Service Account - Represents a service account within a project.
- Project
Service Account ApiKey - Represents the API key generated for a new service account (only present on creation).
- Project
Service Account Create Response - Response object returned when creating a project service account.
- Project
Service Account List Response - Response containing a list of project service accounts.
- Project
User - Represents a user’s membership within a specific project.
- Project
User List Response - Response containing a list of users within a project.
- User
- Represents a user within an organization.
- User
List Response - Response containing a list of organization users.