pub struct RunStepDeltaStepDetailsToolCallsFunctionObject {
pub index: i32,
pub id: Option<String>,
pub type: String,
pub function: Option<RunStepDeltaFunction>,
}Expand description
Represents a delta for a Function tool call during streaming.
Used By
RunStepDeltaToolCall::Function
Fields
index: i32The index of the tool call in the tool calls array.
id: Option<String>The ID of the tool call object, if changed.
type: StringAlways function.
function: Option<RunStepDeltaFunction>The function details delta.