#[non_exhaustive]pub struct FunctionToolCall {
pub arguments: String,
pub call_id: String,
pub id: String,
pub name: String,
pub status: String,
}Expand description
Represents a call to a function tool, generated by the model.
Used By
ResponseOutputItem::FunctionCall(withinresponses.rs)RealtimeConversationItem(withinrealtime_shared.rs)RunStepToolCall::Function(withinassistants_shared.rs)
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.arguments: StringA JSON string of the arguments to pass to the function.
call_id: StringThe unique ID of the function tool call generated by the model.
id: StringThe unique ID of the function tool call. Populated when returned via API.
name: StringThe name of the function to run.
status: StringThe status of the item (in_progress, completed, incomplete). Populated when returned via API.