Module orphan

Module orphan 

Orphan namespace of the module.

Structs

ComputerTool
Defines the computer use tool. A tool that controls a virtual computer. Learn more about the computer tool.
ComputerToolCall
Represents a call to the computer use tool. See the computer use guide for more information.
ComputerToolCallOutput
Represents the output returned from a computer tool call action.
ComputerToolCallSafetyCheck
Represents a safety check associated with a computer tool call.
FileSearchRankingOptions
Represents ranking options for file search results.
FileSearchTool
Defines a file search tool.
FileSearchToolCall
Represents a call to the file search tool, including queries and results.
FunctionParameters
Represents the parameters for a function tool, described as a JSON Schema object. See the guide for examples, and the JSON Schema reference for documentation about the format. Omitting parameters defines a function with an empty parameter list.
FunctionTool
Defines a function tool that the model can call.
FunctionToolCall
Represents a call to a function tool, generated by the model.
FunctionToolCallOutput
Represents the output returned from a function tool call, to be sent back to the model.
ToolChoiceFunction
Specifies a function name for the ToolChoice::Function variant.
WebSearchContextSize
Represents web search context size options. High level guidance for the amount of context window space to use for the search.
WebSearchLocation
Represents approximate location parameters for the web search.
WebSearchTool
Defines a web search tool. This tool searches the web for relevant results to use in a response. Learn more about the web search tool.
WebSearchToolCall
Represents a call to the web search tool. The results of a web search tool call. See the web search guide for more information.
WebSearchUserLocation
User location information for web search personalization

Enums

ComputerAction
Represents different actions the computer use tool can perform.
Tool
Represents the available tools that can be used by models or assistants.
ToolChoice
Represents the choice of which tool the model should use.