pub struct FineTuneChatRequestInput {
pub messages: Vec<ChatCompletionResponseMessage>,
pub tools: Option<Vec<ChatCompletionTool>>,
pub parallel_tool_calls: Option<ParallelToolCalls>,
}Expand description
Represents the input structure for a chat-based fine-tuning job using the supervised method. This is typically one line in the training JSONL file.
Used By
- Training data files for supervised chat fine-tuning.
Fields
messages: Vec<ChatCompletionResponseMessage>A list of messages representing the conversation turn.
tools: Option<Vec<ChatCompletionTool>>Optional list of tools available for this example.
parallel_tool_calls: Option<ParallelToolCalls>Optional setting for parallel tool calls in this example.