pub struct ListFineTuningJobCheckpointsResponse {
pub data: Vec<FineTuningJobCheckpoint>,
pub object: String,
pub first_id: Option<String>,
pub last_id: Option<String>,
pub has_more: bool,
}Expand description
Response containing a list of fine-tuning job checkpoints.
Used By
/fine_tuning/jobs/{fine_tuning_job_id}/checkpoints(GET)
Fields
data: Vec<FineTuningJobCheckpoint>A list of fine-tuning job checkpoint objects.
object: StringThe object type, always “list”.
first_id: Option<String>The ID of the first checkpoint in the list, used for pagination.
last_id: Option<String>The ID of the last checkpoint in the list, used for pagination.
has_more: boolIndicates whether there are more checkpoints available.