FineTuningJob

Struct FineTuningJob 

pub struct FineTuningJob {
Show 19 fields pub id: String, pub created_at: i64, pub error: Option<FineTuningJobError>, pub fine_tuned_model: Option<String>, pub finished_at: Option<i64>, pub hyperparameters: Option<FineTuningJobHyperparameters>, pub model: String, pub object: String, pub organization_id: String, pub result_files: Vec<String>, pub status: String, pub trained_tokens: Option<i64>, pub training_file: String, pub validation_file: Option<String>, pub integrations: Option<Vec<FineTuningIntegration>>, pub seed: i32, pub estimated_finish: Option<i64>, pub method: Option<FineTuneMethod>, pub metadata: Option<Metadata>,
}
The fine_tuning.job object represents a fine-tuning job that has been created through the API.

Used By

  • /fine_tuning/jobs (GET - in ListPaginatedFineTuningJobsResponse, POST response)
  • /fine_tuning/jobs/{fine_tuning_job_id} (GET, POST response)
  • /fine_tuning/jobs/{fine_tuning_job_id}/cancel (POST response)
  • FineTuningJobCheckpoint

Fields

id: String

The object identifier, which can be referenced in the API endpoints.

created_at: i64

The Unix timestamp (in seconds) for when the fine-tuning job was created.

error: Option<FineTuningJobError>

For fine-tuning jobs that have failed, this will contain more information on the cause of the failure.

fine_tuned_model: Option<String>

The name of the fine-tuned model that is being created. Null if the job is still running.

finished_at: Option<i64>

The Unix timestamp (in seconds) for when the fine-tuning job was finished. Null if the job is still running.

hyperparameters: Option<FineTuningJobHyperparameters>
👎Deprecated: Use method.hyperparameters instead

Deprecated : The hyperparameters used for the fine-tuning job. See method.

model: String

The base model that is being fine-tuned.

object: String

The object type, which is always “fine_tuning.job”.

organization_id: String

The organization that owns the fine-tuning job.

result_files: Vec<String>

The compiled results file ID(s) for the fine-tuning job.

status: String

The current status of the fine-tuning job.

trained_tokens: Option<i64>

The total number of billable tokens processed by this job. Null if the job is still running.

training_file: String

The file ID used for training.

validation_file: Option<String>

The file ID used for validation. Null if no validation file was provided.

integrations: Option<Vec<FineTuningIntegration>>

A list of integrations to enable for this fine-tuning job.

seed: i32

The seed used for the fine-tuning job.

estimated_finish: Option<i64>

The Unix timestamp (in seconds) for when the job is estimated to finish. Null if not running.

method: Option<FineTuneMethod>

The fine-tuning method used.

metadata: Option<Metadata>

Set of 16 key-value pairs attached to the object.