pub struct ModerationResult {
pub flagged: bool,
pub categories: ModerationCategories,
pub category_scores: ModerationCategoryScores,
pub category_applied_input_types: Option<ModerationCategoryAppliedInputTypes>,
}Expand description
Fields
flagged: boolWhether the content violates OpenAI’s usage policies.
categories: ModerationCategoriesA list of the categories, and whether they are flagged or not.
category_scores: ModerationCategoryScoresA list of the categories along with their scores as predicted by model.
category_applied_input_types: Option<ModerationCategoryAppliedInputTypes>A list of the categories along with the input type(s) that the score applies to.