pub struct RunStepDetailsToolCallsFileSearchObject {
pub id: String,
pub type: String,
pub file_search: Value,
}Expand description
Details of the File Search tool call the run step was involved in.
Used By
RunStepToolCall::FileSearch
Fields
id: StringThe ID of the tool call object.
type: StringAlways file_search.
file_search: ValueFor now, this is always going to be an empty object.