pub struct CreateTranslationResponseVerboseJson {
pub language: String,
pub duration: f64,
pub text: String,
pub segments: Option<Vec<TranscriptionSegment>>,
}Expand description
Represents a verbose translation response including language, duration, and segments.
Used By
/audio/translations(POST response, whenresponse_formatisverbose_json)
Fields
language: StringThe language of the output translation (always english).
duration: f64The duration of the input audio in seconds.
text: StringThe translated text.
segments: Option<Vec<TranscriptionSegment>>Segments of the translated text and their corresponding details.