pub struct Embedding {
pub index: i32,
pub embedding: Vec<f64>,
pub object: String,
}Expand description
Fields
index: i32The index of the embedding in the list of embeddings.
embedding: Vec<f64>The embedding vector, which is a list of floats. The length depends on the model.
object: StringThe object type, which is always “embedding”.