#[non_exhaustive]pub struct FileSearchRankingOptions {
pub ranker: Option<String>,
pub score_threshold: Option<f64>,
}Expand description
Represents ranking options for file search results.
Used By
FileSearchToolAssistantFileSearchSettings(withinassistants_shared.rs)RunStepDetailsToolCallsFileSearchRankingOptionsObject(withinassistants_shared.rs)
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.ranker: Option<String>The ranker to use for the file search (auto or default_2024_08_21). Defaults to auto.
score_threshold: Option<f64>The score threshold for the file search (0 to 1). Defaults to 0.
Implementations
Sourceimpl FileSearchRankingOptions
impl FileSearchRankingOptions
Sourcepub fn former() -> FileSearchRankingOptionsFormer<FileSearchRankingOptionsFormerDefinition<(), FileSearchRankingOptions, ReturnPreformed>>
pub fn former() -> FileSearchRankingOptionsFormer<FileSearchRankingOptionsFormerDefinition<(), FileSearchRankingOptions, ReturnPreformed>>
Provides a mechanism to initiate the formation process with a default completion behavior.