Upload

Struct Upload 

#[non_exhaustive]
pub struct Upload { pub bytes: i64, pub created_at: i64, pub expires_at: i64, pub file: Option<FileObject>, pub filename: String, pub id: String, pub object: String, pub purpose: String, pub status: String, }
Represents an intermediate Upload object that you can add Parts to. Once completed, it results in a standard File object.

Used By

  • /uploads (POST response)
  • /uploads/{upload_id}/cancel (POST response)
  • /uploads/{upload_id}/complete (POST response)
  • UploadPart

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
bytes: i64

The intended number of bytes to be uploaded.

created_at: i64

The Unix timestamp (in seconds) for when the Upload was created.

expires_at: i64

The Unix timestamp (in seconds) for when the Upload will expire.

file: Option<FileObject>

The ready File object after the Upload is completed. Only present when status is completed.

filename: String

The name of the file to be uploaded.

id: String

The Upload unique identifier, which can be referenced in API endpoints.

object: String

The object type, which is always “upload”.

purpose: String

The intended purpose of the file (e.g., assistants, batch, fine-tune).

status: String

The status of the Upload (pending, completed, cancelled, expired).