Module vector_stores_shared

Module vector_stores_shared 

Structures related to Vector Stores, including files, batches, and search results.

Modules

exposed
Exposed namespace of the module.
orphan
Orphan namespace of the module.
own
Own namespace of the module.
prelude
Prelude to use essentials: use my_module ::prelude :: *.

Structs

AutoChunkingStrategyRequestParam
Represents the auto chunking strategy parameter for requests.
ComparisonFilter
Represents a filter comparing an attribute key to a value.
CompoundFilter
Represents a filter combining multiple filters using and or or.
ListVectorStoreFilesResponse
Response containing a list of vector store files.
ListVectorStoresResponse
Response containing a list of vector stores.
OtherChunkingStrategyResponseParam
Represents an unknown or older chunking strategy in responses.
StaticChunkingStrategy
Represents the static chunking strategy configuration.
StaticChunkingStrategyRequestParam
Represents the static chunking strategy parameter for requests.
StaticChunkingStrategyResponseParam
Represents the static chunking strategy as returned in responses.
VectorStoreExpirationAfter
Represents the expiration policy for a vector store.
VectorStoreFileBatchObject
Represents a batch operation for adding files to a vector store.
VectorStoreFileContentResponse
Represents the response containing the parsed content of a vector store file.
VectorStoreFileCounts
Represents the counts of files in different statuses within a vector store or batch.
VectorStoreFileObject
Represents a file attached to a vector store.
VectorStoreObject
Represents a vector store object. A vector store is a collection of processed files can be used by the file_search tool.
VectorStoreSearchResultContentObject
Represents the content of a search result chunk.
VectorStoreSearchResultItem
Represents a single search result item from a vector store search.
VectorStoreSearchResultsPage
Represents a paginated response from a vector store search.

Enums

ChunkingStrategyRequestParam
Represents the chunking strategy parameter for requests (auto or static).
ChunkingStrategyResponse
Represents the chunking strategy used for a file in a vector store (response format).
Filter
Represents a filter used in vector store search requests.