MessageContentTextAnnotationsFileCitationObject

Struct MessageContentTextAnnotationsFileCitationObject 

pub struct MessageContentTextAnnotationsFileCitationObject {
    pub type: String,
    pub text: String,
    pub file_citation: FileCitationAnnotation,
    pub start_index: i32,
    pub end_index: i32,
}
A citation within the message that points to a specific quote from a specific File.

Used By

  • Annotation::FileCitation (within output.rs)

Fields

type: String

Always file_citation.

text: String

The text in the message content that needs to be replaced.

file_citation: FileCitationAnnotation

Details of the file citation.

start_index: i32

Start index of the citation in the text.

end_index: i32

End index of the citation in the text.