pub struct MessageObject {Show 14 fields
pub id: String,
pub object: String,
pub created_at: i64,
pub thread_id: String,
pub status: String,
pub incomplete_details: Option<IncompleteDetails>,
pub completed_at: Option<i64>,
pub incomplete_at: Option<i64>,
pub role: String,
pub content: Vec<MessageContent>,
pub assistant_id: Option<String>,
pub run_id: Option<String>,
pub attachments: Option<Vec<MessageAttachment>>,
pub metadata: Option<Metadata>,
}Expand description
Represents a message within a thread.
Used By
/threads/{thread_id}/messages(GET - inListMessagesResponse, POST response)/threads/{thread_id}/messages/{message_id}(GET, POST response)AssistantStreamEvent::ThreadMessageCreatedAssistantStreamEvent::ThreadMessageInProgressAssistantStreamEvent::ThreadMessageCompletedAssistantStreamEvent::ThreadMessageIncomplete
Fields
id: StringThe identifier, which can be referenced in API endpoints.
object: StringThe object type, which is always thread.message.
created_at: i64The Unix timestamp (in seconds) for when the message was created.
thread_id: StringThe thread ID that this message belongs to.
status: StringThe status of the message (in_progress, incomplete, or completed).
incomplete_details: Option<IncompleteDetails>Details on why the message is incomplete, if applicable.
completed_at: Option<i64>The Unix timestamp (in seconds) for when the message was completed.
incomplete_at: Option<i64>The Unix timestamp (in seconds) for when the message was marked as incomplete.
role: StringThe entity that produced the message (user or assistant).
content: Vec<MessageContent>The content of the message in array of text and/or images.
assistant_id: Option<String>If applicable, the ID of the assistant that authored this message.
run_id: Option<String>The ID of the run associated with the creation of this message. Null for manually created messages.
attachments: Option<Vec<MessageAttachment>>A list of files attached to the message.
metadata: Option<Metadata>Set of 16 key-value pairs attached to the object.