Module audit_logs_shared

Module audit_logs_shared 

Structures related to Audit Logs API endpoints.

Modules

exposed
Exposed namespace of the module.
orphan
Orphan namespace of the module.
own
Own namespace of the module.
prelude
Prelude to use essentials: use my_module ::prelude :: *.

Structs

AuditLog
Represents a single audit log entry.
AuditLogActor
Represents the actor who performed the audit logged action.
AuditLogActorApiKey
Represents the API key used by an audit log event actor.
AuditLogActorServiceAccount
Represents a service account associated with an audit log event actor (via API key).
AuditLogActorSession
Represents the session context for an audit log event actor.
AuditLogActorUser
Represents the user associated with an audit log event actor.
AuditLogApiKeyCreated
Details for an api_key.created audit log event.
AuditLogApiKeyCreatedData
Data specific to an api_key.created event.
AuditLogApiKeyDeleted
Details for an api_key.deleted audit log event.
AuditLogApiKeyUpdated
Details for an api_key.updated audit log event.
AuditLogApiKeyUpdatedChanges
Changes requested during an api_key.updated event.
AuditLogEventType
Represents the type of an audit log event.
AuditLogInviteAccepted
Details for an invite.accepted audit log event.
AuditLogInviteDeleted
Details for an invite.deleted audit log event.
AuditLogInviteSent
Details for an invite.sent audit log event.
AuditLogInviteSentData
Data specific to an invite.sent event.
AuditLogLoginFailed
Details for a login.failed audit log event.
AuditLogLogoutFailed
Details for a logout.failed audit log event.
AuditLogOrganizationUpdated
Details for an organization.updated audit log event.
AuditLogOrganizationUpdatedChanges
Changes requested during an organization.updated event.
AuditLogOrganizationUpdatedSettings
Settings changed during an organization.updated event.
AuditLogProject
Represents the project context for an audit log event.
AuditLogProjectArchived
Details for a project.archived audit log event.
AuditLogProjectCreated
Details for a project.created audit log event.
AuditLogProjectCreatedData
Data specific to a project.created event.
AuditLogProjectUpdated
Details for a project.updated audit log event.
AuditLogProjectUpdatedChanges
Changes requested during a project.updated event.
AuditLogRateLimitDeleted
Details for a rate_limit.deleted audit log event.
AuditLogRateLimitUpdated
Details for a rate_limit.updated audit log event.
AuditLogRateLimitUpdatedChanges
Changes requested during a rate_limit.updated event.
AuditLogServiceAccountCreated
Details for a service_account.created audit log event.
AuditLogServiceAccountCreatedData
Data specific to a service_account.created event.
AuditLogServiceAccountDeleted
Details for a service_account.deleted audit log event.
AuditLogServiceAccountUpdated
Details for a service_account.updated audit log event.
AuditLogServiceAccountUpdatedChanges
Changes requested during a service_account.updated event.
AuditLogUserAdded
Details for a user.added audit log event.
AuditLogUserAddedData
Data specific to a user.added event (user added to a project).
AuditLogUserDeleted
Details for a user.deleted audit log event (user removed from a project).
AuditLogUserUpdated
Details for a user.updated audit log event.
AuditLogUserUpdatedChanges
Changes requested during a user.updated event (user role changed in a project).
IpAddressDetails
Represents details about the IP address associated with an audit log event.
ListAuditLogsResponse
Response containing a list of audit logs.