pub struct ChatCompletionRequest {Show 17 fields
pub model: String,
pub messages: Vec<ChatCompletionRequestMessage>,
pub temperature: Option<f32>,
pub top_p: Option<f32>,
pub max_tokens: Option<i32>,
pub n: Option<i32>,
pub stop: Option<Vec<String>>,
pub stream: Option<bool>,
pub system_prompt: Option<String>,
pub user: Option<String>,
pub tools: Option<Vec<ChatCompletionTool>>,
pub tool_choice: Option<ToolChoiceOption>,
pub response_format: Option<ChatCompletionResponseFormat>,
pub seed: Option<i64>,
pub logit_bias: Option<Value>,
pub logprobs: Option<bool>,
pub top_logprobs: Option<i32>,
}Expand description
Fields
model: StringID of the model to use.
messages: Vec<ChatCompletionRequestMessage>A list of messages comprising the conversation so far.
temperature: Option<f32>What sampling temperature to use, between 0 and 2.
top_p: Option<f32>An alternative to sampling with temperature, called nucleus sampling.
max_tokens: Option<i32>The maximum number of tokens to generate in the chat completion.
n: Option<i32>Number of chat completion choices to generate for each input message.
stop: Option<Vec<String>>Up to 4 sequences where the API will stop generating further tokens.
stream: Option<bool>Whether to stream back partial progress.
system_prompt: Option<String>The system prompt that helps guide the behavior of the model.
user: Option<String>A unique identifier representing your end-user.
tools: Option<Vec<ChatCompletionTool>>A list of tools the model may call.
tool_choice: Option<ToolChoiceOption>Controls which (if any) tool the model calls.
response_format: Option<ChatCompletionResponseFormat>An object specifying the format that the model must output.
seed: Option<i64>This feature is in Beta.
logit_bias: Option<Value>Adjusts the likelihood of specified tokens appearing in the completion.
logprobs: Option<bool>Log probability of the most likely tokens.
top_logprobs: Option<i32>The number of most likely tokens to return at each token position.
Implementations
Sourceimpl ChatCompletionRequest
impl ChatCompletionRequest
Sourcepub fn former() -> ChatCompletionRequestFormer<ChatCompletionRequestFormerDefinition<(), ChatCompletionRequest, ReturnPreformed>>
pub fn former() -> ChatCompletionRequestFormer<ChatCompletionRequestFormerDefinition<(), ChatCompletionRequest, ReturnPreformed>>
Provides a mechanism to initiate the formation process with a default completion behavior.