pub struct ChatCompletionRequestMessage {
pub role: String,
pub content: Option<ChatCompletionRequestMessageContent>,
pub name: Option<String>,
pub tool_calls: Option<Vec<ChatCompletionMessageToolCall>>,
pub tool_call_id: Option<String>,
}Expand description
Fields
role: StringThe role of the message’s author.
content: Option<ChatCompletionRequestMessageContent>The content of the message.
name: Option<String>The name of the author of this message.
tool_calls: Option<Vec<ChatCompletionMessageToolCall>>The tool calls generated by the model, if applicable.
tool_call_id: Option<String>Tool call ID that this message is responding to.
Implementations
Sourceimpl ChatCompletionRequestMessage
impl ChatCompletionRequestMessage
Sourcepub fn former() -> ChatCompletionRequestMessageFormer<ChatCompletionRequestMessageFormerDefinition<(), ChatCompletionRequestMessage, ReturnPreformed>>
pub fn former() -> ChatCompletionRequestMessageFormer<ChatCompletionRequestMessageFormerDefinition<(), ChatCompletionRequestMessage, ReturnPreformed>>
Provides a mechanism to initiate the formation process with a default completion behavior.