#[non_exhaustive]pub struct FileSearchToolCall {
pub id: String,
pub queries: Vec<String>,
pub results: Option<Vec<FileSearchResultItem>>,
pub status: String,
}Expand description
Represents a call to the file search tool, including queries and results.
Used By
ResponseOutputItem::FileSearchCall(withinoutput.rs) // Corrected path
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.id: StringThe unique ID of the file search tool call.
queries: Vec<String>The queries used to search for files.
results: Option<Vec<FileSearchResultItem>>The results of the file search tool call. Null if the call failed or is still in progress.
status: StringThe status of the file search tool call (in_progress, searching, completed, failed).