pub enum RealtimeConversationItemWithReference {
Reference {
id: String,
type: String,
},
Item(RealtimeConversationItem),
}Expand description
Represents a reference to an existing conversation item or a new item definition.
Used in RealtimeResponseCreateParams to build context.
Used By
RealtimeResponseCreateParams
Variants
Reference
A reference to an existing item by ID.
Fields
Item(RealtimeConversationItem)
A full definition of a new item to include in the context.