pub struct RealtimeResponseCreateParams {
pub modalities: Option<Vec<String>>,
pub instructions: Option<String>,
pub voice: Option<VoiceIdsShared>,
pub output_audio_format: Option<String>,
pub tools: Option<Vec<Tool>>,
pub tool_choice: Option<String>,
pub temperature: Option<f64>,
pub max_response_output_tokens: Option<Value>,
pub conversation: Option<String>,
pub metadata: Option<Metadata>,
pub input: Option<Vec<RealtimeConversationItemWithReference>>,
}Expand description
Parameters for creating a new Realtime response via the client event.
Used By
RealtimeClientEventResponseCreate
Fields
modalities: Option<Vec<String>>The set of modalities the model can respond with.
instructions: Option<String>System instructions override for this response.
voice: Option<VoiceIdsShared>Voice override for this response.
output_audio_format: Option<String>Output audio format override for this response.
tools: Option<Vec<Tool>>Tools override for this response.
tool_choice: Option<String>Tool choice override for this response.
temperature: Option<f64>Temperature override for this response.
max_response_output_tokens: Option<Value>Max output tokens override for this response.
conversation: Option<String>Conversation context override (“auto” or “none”).
metadata: Option<Metadata>Metadata override for this response.
input: Option<Vec<RealtimeConversationItemWithReference>>Input items override for this response’s context.
Implementations
Sourceimpl RealtimeResponseCreateParams
impl RealtimeResponseCreateParams
Sourcepub fn former() -> RealtimeResponseCreateParamsFormer<RealtimeResponseCreateParamsFormerDefinition<(), RealtimeResponseCreateParams, ReturnPreformed>>
pub fn former() -> RealtimeResponseCreateParamsFormer<RealtimeResponseCreateParamsFormerDefinition<(), RealtimeResponseCreateParams, ReturnPreformed>>
Provides a mechanism to initiate the formation process with a default completion behavior.