RealtimeConversationItemContent

Struct RealtimeConversationItemContent 

pub struct RealtimeConversationItemContent {
    pub type: Option<String>,
    pub text: Option<String>,
    pub id: Option<String>,
    pub audio: Option<String>,
    pub transcript: Option<String>,
}
Represents an item content within the Realtime conversation item Used when creating/retrieving items via client/server events.

Used By

  • RealtimeClientEventConversationItem

Fields

type: Option<String>

The content type (input_text, input_audio, item_reference, text).

text: Option<String>

The text content, used for input_text and text content types.

id: Option<String>

ID of a previous conversation item to reference (for item_reference content types in response.create events). These can reference both client and server created items.

audio: Option<String>

Base64-encoded audio bytes, used for input_audio content type.

transcript: Option<String>

The transcript of the audio, used for input_audio content type.

Implementations

Source

impl RealtimeConversationItemContent

pub fn former() -> RealtimeConversationItemContentFormer<RealtimeConversationItemContentFormerDefinition<(), RealtimeConversationItemContent, ReturnPreformed>>

Provides a mechanism to initiate the formation process with a default completion behavior.