RealtimeResponse

Struct RealtimeResponse 

pub struct RealtimeResponse {
Show 13 fields pub id: String, pub object: String, pub status: String, pub status_details: Option<RealtimeResponseStatusDetails>, pub output: Vec<RealtimeConversationItem>, pub metadata: Option<Metadata>, pub usage: Option<RealtimeResponseUsage>, pub conversation_id: Option<String>, pub voice: Option<VoiceIdsShared>, pub modalities: Option<Vec<String>>, pub output_audio_format: Option<String>, pub temperature: Option<f64>, pub max_response_output_tokens: Option<Value>,
}
Represents the response resource from the Realtime API.

Used By

  • RealtimeServerEventResponseCreated
  • RealtimeServerEventResponseDone

Fields

id: String

The unique ID of the response.

object: String

The object type, must be realtime.response.

status: String

The final status of the response (completed, cancelled, failed, or incomplete).

status_details: Option<RealtimeResponseStatusDetails>

Additional details about the status.

output: Vec<RealtimeConversationItem>

The list of output items generated by the response.

metadata: Option<Metadata>

Metadata associated with the response.

usage: Option<RealtimeResponseUsage>

Usage statistics for the Response.

conversation_id: Option<String>

Which conversation the response is added to (auto, none, or conv_123).

voice: Option<VoiceIdsShared>

The voice the model used to respond.

modalities: Option<Vec<String>>

The set of modalities the model used to respond.

output_audio_format: Option<String>

The format of output audio.

temperature: Option<f64>

Sampling temperature used for this response.

max_response_output_tokens: Option<Value>

Maximum number of output tokens used in this response.