ResponseItemList

Struct ResponseItemList 

#[non_exhaustive]
pub struct ResponseItemList { pub data: Vec<ListedInputItem>, pub first_id: Option<String>, pub has_more: bool, pub last_id: Option<String>, pub object: String, }
Represents a list of Response items, typically used for input items list. Corresponds to the ResponseItemList schema in the OpenAPI spec.

Used By

  • /responses/{response_id}/input_items (GET)

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
data: Vec<ListedInputItem>

A list of input items (messages) associated with the response.

first_id: Option<String>

The identifier of the first item in the data array.

has_more: bool

Indicates whether there are more items available.

last_id: Option<String>

The identifier of the last item in the data array.

object: String

The object type, always “list”.