ResponseWebSearchCallSearchingEvent

Struct ResponseWebSearchCallSearchingEvent 

#[non_exhaustive]
pub struct ResponseWebSearchCallSearchingEvent { pub item_id: String, pub output_index: u32, }
Event data for response.web_search_call.searching.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
item_id: String

Unique ID for the output item associated with the web search call.

output_index: u32

The index of the output item that the web search call is associated with.