pub struct ConfigChangeSender { /* private fields */ }Expand description
Sender for configuration change events
Implementations
Sourceimpl ConfigChangeSender
impl ConfigChangeSender
Sourcepub fn send_change(&self, event: ConfigChangeEvent) -> Result<(), &'static str>
pub fn send_change(&self, event: ConfigChangeEvent) -> Result<(), &'static str>
Send a configuration change event
Errors
Returns an error if the event cannot be sent (e.g., if the receiver has been dropped).
Sourcepub fn send_update(
&self,
key: String,
old_value: Option<ConfigValue>,
new_value: ConfigValue,
) -> Result<(), &'static str>
pub fn send_update( &self, key: String, old_value: Option<ConfigValue>, new_value: ConfigValue, ) -> Result<(), &'static str>
Send a configuration update event
Errors
Returns an error if the event cannot be sent (e.g., if the receiver has been dropped).