pub async fn create_batch_job(
_client: &Client<OpenaiEnvironmentImpl>,
request: Value,
) -> Result<Batch>Expand description
Enhanced batch job creation with priority and retry configuration
Errors
Returns an error if the batch job creation fails or if request parsing fails.