AssistantStreamEvent

Enum AssistantStreamEvent 

pub enum AssistantStreamEvent {
Show 25 variants ThreadCreated { data: ThreadObject, }, ThreadRunCreated { data: RunObject, }, ThreadRunQueued { data: RunObject, }, ThreadRunInProgress { data: RunObject, }, ThreadRunRequiresAction { data: RunObject, }, ThreadRunCompleted { data: RunObject, }, ThreadRunIncomplete { data: RunObject, }, ThreadRunFailed { data: RunObject, }, ThreadRunCancelling { data: RunObject, }, ThreadRunCancelled { data: RunObject, }, ThreadRunExpired { data: RunObject, }, ThreadRunStepCreated { data: RunStepObject, }, ThreadRunStepInProgress { data: RunStepObject, }, ThreadRunStepDelta { data: RunStepDeltaObject, }, ThreadRunStepCompleted { data: RunStepObject, }, ThreadRunStepFailed { data: RunStepObject, }, ThreadRunStepCancelled { data: RunStepObject, }, ThreadRunStepExpired { data: RunStepObject, }, ThreadMessageCreated { data: MessageObject, }, ThreadMessageInProgress { data: MessageObject, }, ThreadMessageDelta { data: MessageDeltaObject, }, ThreadMessageCompleted { data: MessageObject, }, ThreadMessageIncomplete { data: MessageObject, }, Error { data: Error, }, Done { data: String, },
}
Represents the different types of events emitted during an Assistant stream.

Used By

  • Streaming responses from /threads/runs (POST), /threads/{thread_id}/runs (POST), /threads/{thread_id}/runs/{run_id}/submit_tool_outputs (POST)

Variants



ThreadCreated

Occurs when a new thread is created.

Fields

data: ThreadObject

The created ThreadObject.



ThreadRunCreated

Occurs when a new run is created.

Fields

data: RunObject

The created RunObject.



ThreadRunQueued

Occurs when a run moves to a queued status.

Fields

data: RunObject

The RunObject in the queued state.



ThreadRunInProgress

Occurs when a run moves to an in_progress status.

Fields

data: RunObject

The RunObject in the in-progress state.



ThreadRunRequiresAction

Occurs when a run moves to a requires_action status.

Fields

data: RunObject

The RunObject requiring action.



ThreadRunCompleted

Occurs when a run is completed.

Fields

data: RunObject

The completed RunObject.



ThreadRunIncomplete

Occurs when a run ends with status incomplete.

Fields

data: RunObject

The incomplete RunObject.



ThreadRunFailed

Occurs when a run fails.

Fields

data: RunObject

The failed RunObject.



ThreadRunCancelling

Occurs when a run moves to a cancelling status.

Fields

data: RunObject

The RunObject in the cancelling state.



ThreadRunCancelled

Occurs when a run is cancelled.

Fields

data: RunObject

The cancelled RunObject.



ThreadRunExpired

Occurs when a run expires.

Fields

data: RunObject

The expired RunObject.



ThreadRunStepCreated

Occurs when a run step is created.

Fields

data: RunStepObject

The created RunStepObject.



ThreadRunStepInProgress

Occurs when a run step moves to an in_progress state.

Fields

data: RunStepObject

The RunStepObject in the in-progress state.



ThreadRunStepDelta

Occurs when parts of a run step are being streamed.

Fields

data: RunStepDeltaObject

The RunStepDeltaObject containing the changes.



ThreadRunStepCompleted

Occurs when a run step is completed.

Fields

data: RunStepObject

The completed RunStepObject.



ThreadRunStepFailed

Occurs when a run step fails.

Fields

data: RunStepObject

The failed RunStepObject.



ThreadRunStepCancelled

Occurs when a run step is cancelled.

Fields

data: RunStepObject

The cancelled RunStepObject.



ThreadRunStepExpired

Occurs when a run step expires.

Fields

data: RunStepObject

The expired RunStepObject.



ThreadMessageCreated

Occurs when a message is created.

Fields

data: MessageObject

The created MessageObject.



ThreadMessageInProgress

Occurs when a message moves to an in_progress state.

Fields

data: MessageObject

The MessageObject in the in-progress state.



ThreadMessageDelta

Occurs when parts of a Message are being streamed.

Fields

data: MessageDeltaObject

The MessageDeltaObject containing the changes.



ThreadMessageCompleted

Occurs when a message is completed.

Fields

data: MessageObject

The completed MessageObject.



ThreadMessageIncomplete

Occurs when a message ends before it is completed.

Fields

data: MessageObject

The incomplete MessageObject.



Error

Occurs when an error occurs during streaming.

Fields

data: Error

The Error object containing details.



Done

Occurs when a stream ends.

Fields

data: String

The data, always the string “[DONE]”.