Structures shared across the Batch API.
Modules
- exposed
- Exposed namespace of the module.
- orphan
- Orphan namespace of the module.
- own
- Own namespace of the module.
- prelude
- Prelude to use essentials:
use my_module ::prelude :: *.
Structs
- Admin
ApiKey - Represents an Admin API Key.
- Admin
ApiKey Owner - Represents the owner of an Admin API Key (User or Service Account).
- ApiKey
List - Response containing a list of Admin API Keys.
- Batch
- Represents a Batch job object.
- Batch
Error Data - Represents error details within a Batch object.
- Batch
Errors - Represents the list of errors for a Batch job.
- Batch
Request Counts - Represents the request counts for different statuses within a batch job.
- Batch
Request Input - Represents the input structure for a single request within a batch file (JSONL format).
- Batch
Request Output - Represents the output structure for a single request within a batch output/error file (JSONL format).
- Batch
Request Output Error - Represents error details for a failed request within a batch output file.
- Batch
Request Output Response - Represents the response structure for a single request within a batch output file.
- Invite
- Represents an invitation to join an organization.
- Invite
List Response - Response containing a list of organization invites.
- Invite
Project - Represents project membership granted upon invite acceptance.
- List
Batches Response - Response containing a list of Batch jobs.
- Project
- Represents an organization project.
- Project
ApiKey - Represents an API key associated with a project.
- Project
ApiKey List Response - Response containing a list of project API keys.
- Project
ApiKey Owner - Represents the owner of a Project API Key (either a User or Service Account).
- Project
List Response - Response containing a list of organization projects.
- Project
Rate Limit - Represents rate limit configuration for a specific model within a project.
- Project
Rate Limit List Response - Response containing a list of project rate limits.
- Project
Service Account - Represents a service account within a project.
- Project
Service Account ApiKey - Represents the API key generated for a new service account (only present on creation).
- Project
Service Account Create Response - Response object returned when creating a project service account.
- Project
Service Account List Response - Response containing a list of project service accounts.
- Project
User - Represents a user’s membership within a specific project.
- Project
User List Response - Response containing a list of users within a project.
- User
- Represents a user within an organization.
- User
List Response - Response containing a list of organization users.