pub struct InputFile {
pub file_id: Option<String>,
pub filename: Option<String>,
pub file_data: Option<String>,
}Expand description
Represents a file input part, specified by File ID or embedded data. Learn about file inputs for text generation.
Used By
InputContentPartChatCompletionRequestMessageContentPartFile(withinchat_shared.rs)
Fields
file_id: Option<String>The ID of an uploaded file to use as input.
filename: Option<String>The name of the file, used when passing the file to the model as a string.
file_data: Option<String>The base64 encoded file data, used when passing the file to the model as a string.
Implementations