pub struct MessageContentTextAnnotationsFilePathObject {
pub type: String,
pub text: String,
pub file_path: FilePathAnnotation,
pub start_index: i32,
pub end_index: i32,
}Expand description
A URL for the file that’s generated when the assistant used the code_interpreter tool.
Used By
Annotation::FilePath(withinoutput.rs)
Fields
type: StringAlways file_path.
text: StringThe text in the message content that needs to be replaced.
file_path: FilePathAnnotationDetails of the file path.
start_index: i32Start index of the file path in the text.
end_index: i32End index of the file path in the text.