pub struct Image {
pub b64_json: Option<String>,
pub url: Option<String>,
pub revised_prompt: Option<String>,
}Expand description
Fields
b64_json: Option<String>The base64-encoded JSON of the generated image, if response_format is b64_json.
url: Option<String>The URL of the generated image, if response_format is url (default). URLs are only valid for 60 minutes.
revised_prompt: Option<String>The prompt that was used to generate the image, if there was any revision to the prompt.