pub struct InputImage {
pub image_url: Option<String>,
pub file_id: Option<String>,
pub detail: Option<String>,
}Expand description
Represents an image input part, specified either by URL or File ID. Learn about image inputs.
Used By
InputContentPartChatCompletionRequestMessageContentPartImage(withinchat_shared.rs)
Fields
image_url: Option<String>The URL of the image or a base64 encoded data URL.
file_id: Option<String>The ID of an uploaded file to use as input.
detail: Option<String>Specifies the detail level of the image (low, high, or auto). Defaults to auto.
Implementations
Sourceimpl InputImage
impl InputImage
Sourcepub fn former() -> InputImageFormer<InputImageFormerDefinition<(), InputImage, ReturnPreformed>>
pub fn former() -> InputImageFormer<InputImageFormerDefinition<(), InputImage, ReturnPreformed>>
Provides a mechanism to initiate the formation process with a default completion behavior.