pub enum Annotation {
FileCitation {
text: String,
file_citation: FileCitationAnnotation,
start_index: u32,
end_index: u32,
},
UrlCitation {
url: String,
title: String,
start_index: u32,
end_index: u32,
},
FilePath {
text: String,
file_path: FilePathAnnotation,
start_index: u32,
end_index: u32,
},
}Expand description
Represents annotations embedded within output text content. These annotations provide context or references for parts of the text.
Used By
OutputContentPart::TextMessageContentTextObject(withinassistants_shared.rs)MessageDeltaTextContent(withinassistants_shared.rs)ResponseTextAnnotationDeltaEvent(withinrealtime_shared.rs)
Variants
FileCitation
A citation within the message that points to a specific quote from a specific File.
Fields

file_citation: FileCitationAnnotationThe details of the file citation.
UrlCitation
A citation for a web resource used to generate a model response.
Fields
FilePath
A URL for the file that’s generated when the assistant used the code_interpreter tool.