#[non_exhaustive]pub struct ResponseTextAnnotationDeltaEvent {
pub annotation: Annotation,
pub annotation_index: u32,
pub content_index: u32,
pub item_id: String,
pub output_index: u32,
}Expand description
Event data for response.output_text.annotation.added.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.annotation: AnnotationThe annotation that was added.
annotation_index: u32The index of the annotation that was added.
content_index: u32The index of the content part that the text annotation was added to.
item_id: StringThe ID of the output item that the text annotation was added to.
output_index: u32The index of the output item that the text annotation was added to.