#[non_exhaustive]pub struct CreateResponseRequest {Show 18 fields
pub input: ResponseInput,
pub include: Option<Vec<Includable>>,
pub instructions: Option<String>,
pub max_output_tokens: Option<i32>,
pub metadata: Option<Metadata>,
pub model: ModelIdsResponses,
pub parallel_tool_calls: bool,
pub previous_response_id: Option<String>,
pub reasoning: Option<Reasoning>,
pub store: Option<bool>,
pub stream: Option<bool>,
pub temperature: Option<f32>,
pub text: Option<TextResponseFormatConfigurationOptions>,
pub tool_choice: Option<ToolChoice>,
pub tools: Option<Vec<Tool>>,
pub top_p: Option<f32>,
pub truncation: Option<String>,
pub user: Option<String>,
}Expand description
Represents the request body for creating a model response.
Corresponds to the request body of POST /responses.
Used By
api::responses::Responses::create
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.input: ResponseInputText, image, or file inputs to the model.
include: Option<Vec<Includable>>Additional output data to include (e.g., “file_search_call.results”).
instructions: Option<String>System instructions for the model.
max_output_tokens: Option<i32>Maximum output tokens allowed.
metadata: Option<Metadata>Metadata associated with the request.
model: ModelIdsResponsesModel ID used to generate the response.
parallel_tool_calls: boolWhether to allow parallel tool calls. Defaults to true.
previous_response_id: Option<String>ID of the previous response in the conversation.
reasoning: Option<Reasoning>Reasoning configuration.
store: Option<bool>Whether to store the generated response. Defaults to true.
stream: Option<bool>Whether to stream the response. Defaults to false.
temperature: Option<f32>Sampling temperature.
text: Option<TextResponseFormatConfigurationOptions>Text response format configuration.
tool_choice: Option<ToolChoice>Strategy for choosing tools.
tools: Option<Vec<Tool>>List of available tools.
top_p: Option<f32>Nucleus sampling probability.
truncation: Option<String>Truncation strategy (“auto” or “disabled”).
user: Option<String>End-user identifier.
Implementations
Sourceimpl CreateResponseRequest
impl CreateResponseRequest
Sourcepub fn former() -> CreateResponseRequestFormer<CreateResponseRequestFormerDefinition<(), CreateResponseRequest, ReturnPreformed>>
pub fn former() -> CreateResponseRequestFormer<CreateResponseRequestFormerDefinition<(), CreateResponseRequest, ReturnPreformed>>
Provides a mechanism to initiate the formation process with a default completion behavior.