pub struct CreateEmbeddingRequest {
pub input: EmbeddingInput,
pub model: String,
pub dimensions: Option<u32>,
pub encoding_format: Option<String>,
pub user: Option<String>,
}Expand description
Request for creating embeddings
Fields
input: EmbeddingInputInput text to embed, encoded as a string or array of strings
model: StringID of the model to use
dimensions: Option<u32>The number of dimensions the resulting output embeddings should have. Only supported in text-embedding-3 and later models.
encoding_format: Option<String>The format to return the embeddings in. Can be either float or base64.
user: Option<String>A unique identifier representing your end-user, which can help OpenAI to monitor and detect abuse.
Implementations
Sourceimpl CreateEmbeddingRequest
impl CreateEmbeddingRequest
Sourcepub fn former() -> CreateEmbeddingRequestFormer<CreateEmbeddingRequestFormerDefinition<(), CreateEmbeddingRequest, ReturnPreformed>>
pub fn former() -> CreateEmbeddingRequestFormer<CreateEmbeddingRequestFormerDefinition<(), CreateEmbeddingRequest, ReturnPreformed>>
Provides a mechanism to initiate the formation process with a default completion behavior.
Sourceimpl CreateEmbeddingRequest
impl CreateEmbeddingRequest
Sourcepub fn new_single(input: String, model: String) -> Self
pub fn new_single(input: String, model: String) -> Self
Create a new embedding request with single text input
Sourcepub fn new_multiple(input: Vec<String>, model: String) -> Self
pub fn new_multiple(input: Vec<String>, model: String) -> Self
Create a new embedding request with multiple text inputs