CreateImageEditRequest

Struct CreateImageEditRequest 

pub struct CreateImageEditRequest {
    pub image: Vec<u8>,
    pub image_filename: String,
    pub mask: Option<Vec<u8>>,
    pub mask_filename: Option<String>,
    pub prompt: String,
    pub model: Option<String>,
    pub n: Option<i32>,
    pub size: Option<String>,
    pub response_format: Option<String>,
    pub user: Option<String>,
}
Request parameters for editing an image.

Used By

  • /images/edits (POST request)

Fields

image: Vec<u8>

The image to edit. Must be a valid PNG file, less than 4MB, and square.

image_filename: String

The filename for the image file.

mask: Option<Vec<u8>>

An additional image whose fully transparent areas indicate where image should be edited. Must be a PNG file, less than 4MB, and have the same dimensions as image.

mask_filename: Option<String>

The filename for the mask file (if mask is provided).

prompt: String

A text description of the desired image(s). The maximum length is 1000 characters.

model: Option<String>

The model to use for image generation.

n: Option<i32>

The number of images to generate. Must be between 1 and 10.

size: Option<String>

The size of the generated images.

response_format: Option<String>

The format in which the generated images are returned.

user: Option<String>

A unique identifier representing your end-user.