pub struct RealtimeTranscriptionSessionCreateRequest {
pub modalities: Option<Vec<String>>,
pub input_audio_format: Option<String>,
pub input_audio_transcription: Option<RealtimeSessionInputAudioTranscription>,
pub turn_detection: Option<RealtimeSessionTurnDetection>,
pub input_audio_noise_reduction: Option<RealtimeSessionInputAudioNoiseReduction>,
pub include: Option<Vec<String>>,
}Expand description
Represents the request body for creating or updating a Realtime transcription session.
Used By
/realtime/transcription_sessions(POST)RealtimeClientEventTranscriptionSessionUpdate
Fields
modalities: Option<Vec<String>>Supported modalities (always ["audio", "text"] for transcription).
input_audio_format: Option<String>Format of input audio.
input_audio_transcription: Option<RealtimeSessionInputAudioTranscription>Input audio transcription configuration.
turn_detection: Option<RealtimeSessionTurnDetection>Turn detection configuration.
input_audio_noise_reduction: Option<RealtimeSessionInputAudioNoiseReduction>Input audio noise reduction configuration.
include: Option<Vec<String>>Items to include in the transcription response (e.g., logprobs).
Implementations
Sourceimpl RealtimeTranscriptionSessionCreateRequest
impl RealtimeTranscriptionSessionCreateRequest
Sourcepub fn former() -> RealtimeTranscriptionSessionCreateRequestFormer<RealtimeTranscriptionSessionCreateRequestFormerDefinition<(), RealtimeTranscriptionSessionCreateRequest, ReturnPreformed>>
pub fn former() -> RealtimeTranscriptionSessionCreateRequestFormer<RealtimeTranscriptionSessionCreateRequestFormerDefinition<(), RealtimeTranscriptionSessionCreateRequest, ReturnPreformed>>
Provides a mechanism to initiate the formation process with a default completion behavior.