TuningManager

Struct TuningManager 

pub struct TuningManager { /* private fields */ }
Model tuning manager

Implementations

Source

impl TuningManager

pub fn new() -> Self

Create a new tuning manager

pub async fn create_job( &mut self, config: TuningJobConfig, ) -> Result<String, String>

Create a new tuning job

Errors

Returns an error if a job with the same name already exists.

pub async fn get_job(&self, job_name: &str) -> Option<&TuningJob>

Get a tuning job by name

pub async fn get_job_mut(&mut self, job_name: &str) -> Option<&mut TuningJob>

Get a mutable reference to a tuning job

pub async fn list_jobs(&self) -> Vec<&TuningJob>

List all tuning jobs

pub async fn update_job_status( &mut self, job_name: &str, status: TuningStatus, ) -> Result<(), String>

Update job status

Errors

Returns an error if the job is not found.

pub async fn cancel_job(&mut self, job_name: &str) -> Result<(), String>

Cancel a tuning job

Errors

Returns an error if the job is not found.

pub async fn delete_job(&mut self, job_name: &str) -> Result<(), String>

Delete a tuning job

Errors

Returns an error if the job is not found.

pub fn tuning_stats(&self) -> TuningStats

Get tuning statistics