pub struct RunStepDetailsToolCallsCodeOutputLogsObject {
pub type: String,
pub logs: String,
}Expand description
Text output from the Code Interpreter tool call as part of a run step.
Used By
CodeInterpreterOutput::Logs
Fields
type: StringAlways logs.
logs: StringThe text output from the Code Interpreter tool call.