pub struct RunStepObject {Show 16 fields
pub id: String,
pub object: String,
pub created_at: i64,
pub assistant_id: String,
pub thread_id: String,
pub run_id: String,
pub type: String,
pub status: String,
pub step_details: RunStepDetails,
pub last_error: Option<RunLastError>,
pub expired_at: Option<i64>,
pub cancelled_at: Option<i64>,
pub failed_at: Option<i64>,
pub completed_at: Option<i64>,
pub metadata: Option<Metadata>,
pub usage: Option<CompletionUsage>,
}Expand description
Represents a step in execution of a run.
Used By
/threads/{thread_id}/runs/{run_id}/steps(GET - inListRunStepsResponse)/threads/{thread_id}/runs/{run_id}/steps/{step_id}(GET)AssistantStreamEvent::ThreadRunStepCreatedand other step status events
Fields
id: StringThe identifier of the run step.
object: StringThe object type, always thread.run.step.
created_at: i64The Unix timestamp (in seconds) for when the run step was created.
assistant_id: StringThe ID of the assistant associated with the run step.
thread_id: StringThe ID of the thread that was run.
run_id: StringThe ID of the run that this run step is a part of.
type: StringThe type of run step (message_creation or tool_calls).
status: StringThe status of the run step.
step_details: RunStepDetailsThe details of the run step.
last_error: Option<RunLastError>The last error associated with this run step. Null if no errors.
expired_at: Option<i64>The Unix timestamp (in seconds) for when the run step expired.
cancelled_at: Option<i64>The Unix timestamp (in seconds) for when the run step was cancelled.
failed_at: Option<i64>The Unix timestamp (in seconds) for when the run step failed.
completed_at: Option<i64>The Unix timestamp (in seconds) for when the run step completed.
metadata: Option<Metadata>Set of 16 key-value pairs attached to the object.
usage: Option<CompletionUsage>Usage statistics related to the run step. Null if status is in_progress.