pub struct Metadata(pub HashMap<String, String>);Expand description
Represents metadata as key-value pairs, allowing attachment of custom information.
Set of 16 key-value pairs that can be attached to an object. This can be useful for storing additional information about the object in a structured format, and querying for objects via API or the dashboard. Keys are strings with a maximum length of 64 characters. Values are strings with a maximum length of 512 characters.
Used By
/assistants(POST)/assistants/{assistant_id}(POST)/batches(POST, GET)/batches/{batch_id}(GET)/chat/completions(GET, POST)/chat/completions/{completion_id}(POST)/fine_tuning/jobs(POST, GET)/fine_tuning/jobs/{fine_tuning_job_id}(GET)/threads(POST)/threads/{thread_id}(POST)/threads/{thread_id}/messages(POST)/threads/{thread_id}/messages/{message_id}(POST)/threads/{thread_id}/runs(POST)/threads/{thread_id}/runs/{run_id}(POST)/threads/{thread_id}/runs/{run_id}/steps/{step_id}(GET)/responses(POST, GET)/responses/{response_id}(GET)/vector_stores(POST)/vector_stores/{vector_store_id}(POST)
Tuple Fields
0: HashMap<String, String>The underlying map storing key-value pairs.