pub enum AssistantStreamEvent {
Show 25 variants
ThreadCreated {
data: ThreadObject,
},
ThreadRunCreated {
data: RunObject,
},
ThreadRunQueued {
data: RunObject,
},
ThreadRunInProgress {
data: RunObject,
},
ThreadRunRequiresAction {
data: RunObject,
},
ThreadRunCompleted {
data: RunObject,
},
ThreadRunIncomplete {
data: RunObject,
},
ThreadRunFailed {
data: RunObject,
},
ThreadRunCancelling {
data: RunObject,
},
ThreadRunCancelled {
data: RunObject,
},
ThreadRunExpired {
data: RunObject,
},
ThreadRunStepCreated {
data: RunStepObject,
},
ThreadRunStepInProgress {
data: RunStepObject,
},
ThreadRunStepDelta {
data: RunStepDeltaObject,
},
ThreadRunStepCompleted {
data: RunStepObject,
},
ThreadRunStepFailed {
data: RunStepObject,
},
ThreadRunStepCancelled {
data: RunStepObject,
},
ThreadRunStepExpired {
data: RunStepObject,
},
ThreadMessageCreated {
data: MessageObject,
},
ThreadMessageInProgress {
data: MessageObject,
},
ThreadMessageDelta {
data: MessageDeltaObject,
},
ThreadMessageCompleted {
data: MessageObject,
},
ThreadMessageIncomplete {
data: MessageObject,
},
Error {
data: Error,
},
Done {
data: String,
},
}Expand description
Represents the different types of events emitted during an Assistant stream.
Used By
- Streaming responses from
/threads/runs(POST),/threads/{thread_id}/runs(POST),/threads/{thread_id}/runs/{run_id}/submit_tool_outputs(POST)
Variants
ThreadCreated
Occurs when a new thread is created.
Fields
data: ThreadObjectThe created ThreadObject.
ThreadRunCreated
Occurs when a new run is created.
ThreadRunQueued
Occurs when a run moves to a queued status.
ThreadRunInProgress
Occurs when a run moves to an in_progress status.
ThreadRunRequiresAction
Occurs when a run moves to a requires_action status.
ThreadRunCompleted
Occurs when a run is completed.
ThreadRunIncomplete
Occurs when a run ends with status incomplete.
ThreadRunFailed
Occurs when a run fails.
ThreadRunCancelling
Occurs when a run moves to a cancelling status.
ThreadRunCancelled
Occurs when a run is cancelled.
ThreadRunExpired
Occurs when a run expires.
ThreadRunStepCreated
Occurs when a run step is created.
Fields
data: RunStepObjectThe created RunStepObject.
ThreadRunStepInProgress
Occurs when a run step moves to an in_progress state.
Fields
data: RunStepObjectThe RunStepObject in the in-progress state.
ThreadRunStepDelta
Occurs when parts of a run step are being streamed.
Fields
data: RunStepDeltaObjectThe RunStepDeltaObject containing the changes.
ThreadRunStepCompleted
Occurs when a run step is completed.
Fields
data: RunStepObjectThe completed RunStepObject.
ThreadRunStepFailed
Occurs when a run step fails.
Fields
data: RunStepObjectThe failed RunStepObject.
ThreadRunStepCancelled
Occurs when a run step is cancelled.
Fields
data: RunStepObjectThe cancelled RunStepObject.
ThreadRunStepExpired
Occurs when a run step expires.
Fields
data: RunStepObjectThe expired RunStepObject.
ThreadMessageCreated
Occurs when a message is created.
Fields
data: MessageObjectThe created MessageObject.
ThreadMessageInProgress
Occurs when a message moves to an in_progress state.
Fields
data: MessageObjectThe MessageObject in the in-progress state.
ThreadMessageDelta
Occurs when parts of a Message are being streamed.
Fields
data: MessageDeltaObjectThe MessageDeltaObject containing the changes.
ThreadMessageCompleted
Occurs when a message is completed.
Fields
data: MessageObjectThe completed MessageObject.
ThreadMessageIncomplete
Occurs when a message ends before it is completed.
Fields
data: MessageObjectThe incomplete MessageObject.
Error
Occurs when an error occurs during streaming.
Done
Occurs when a stream ends.