pub struct RealtimeSession {Show 14 fields
pub id: String,
pub modalities: Option<Vec<String>>,
pub model: String,
pub instructions: Option<String>,
pub voice: Option<VoiceIdsShared>,
pub input_audio_format: Option<String>,
pub output_audio_format: Option<String>,
pub input_audio_transcription: Option<RealtimeSessionInputAudioTranscription>,
pub turn_detection: Option<RealtimeSessionTurnDetection>,
pub input_audio_noise_reduction: Option<RealtimeSessionInputAudioNoiseReduction>,
pub tools: Option<Vec<Tool>>,
pub tool_choice: Option<String>,
pub temperature: Option<f64>,
pub max_response_output_tokens: Option<Value>,
}Expand description
Represents the configuration of an active Realtime session.
Used By
RealtimeServerEventSessionCreatedRealtimeServerEventSessionUpdated
Fields
id: StringUnique identifier for the session.
modalities: Option<Vec<String>>The set of modalities the model can respond with.
model: StringThe Realtime model used for this session.
instructions: Option<String>The default system instructions for the session.
voice: Option<VoiceIdsShared>The voice the model uses to respond.
input_audio_format: Option<String>The format of input audio.
output_audio_format: Option<String>The format of output audio.
input_audio_transcription: Option<RealtimeSessionInputAudioTranscription>Configuration for input audio transcription.
turn_detection: Option<RealtimeSessionTurnDetection>Configuration for turn detection.
input_audio_noise_reduction: Option<RealtimeSessionInputAudioNoiseReduction>Configuration for input audio noise reduction.
tools: Option<Vec<Tool>>Tools (functions) available to the model.
tool_choice: Option<String>How the model chooses tools.
temperature: Option<f64>Sampling temperature for the model.
max_response_output_tokens: Option<Value>Maximum number of output tokens for a single assistant response.