#[non_exhaustive]pub struct ResponseObject {Show 23 fields
pub created_at: i64,
pub error: Option<ResponseError>,
pub id: String,
pub incomplete_details: Option<ResponseIncompleteDetails>,
pub instructions: Option<String>,
pub max_output_tokens: Option<i32>,
pub metadata: Option<Metadata>,
pub model: String,
pub object: String,
pub output: Vec<OutputItem>,
pub parallel_tool_calls: bool,
pub previous_response_id: Option<String>,
pub reasoning: Option<Reasoning>,
pub status: String,
pub stream: Option<bool>,
pub temperature: Option<f32>,
pub text: Option<TextResponseFormatConfigurationOptions>,
pub tool_choice: Option<ToolChoice>,
pub tools: Option<Vec<Tool>>,
pub top_p: Option<f32>,
pub truncation: Option<String>,
pub usage: Option<ResponseUsage>,
pub user: Option<String>,
}Expand description
Represents a response generated by the model via the Responses API.
Corresponds to the Response schema in the OpenAPI spec.
Used By
/responses(POST response)/responses/{response_id}(GET response)RealtimeServerEventResponseCreated(withinrealtime_shared.rs)RealtimeServerEventResponseDone(withinrealtime_shared.rs)RealtimeServerEventResponseFailed(withinrealtime_shared.rs)RealtimeServerEventResponseIncomplete(withinrealtime_shared.rs)RealtimeServerEventResponseInProgress(withinrealtime_shared.rs)
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.created_at: i64Unix timestamp (in seconds) of when this Response was created.
error: Option<ResponseError>The error object if the response status is failed. Null otherwise.
id: StringUnique identifier for this Response.
incomplete_details: Option<ResponseIncompleteDetails>Details about why the response is incomplete, if applicable. Null otherwise.
instructions: Option<String>System instructions provided.
max_output_tokens: Option<i32>Maximum output tokens allowed.
metadata: Option<Metadata>Metadata associated with the response.
model: StringModel ID used for the response. *** CHANGED TO String ***
object: StringThe object type, always “response”.
output: Vec<OutputItem>An array of content items generated by the model.
parallel_tool_calls: boolWhether parallel tool calls were enabled.
previous_response_id: Option<String>ID of the previous response in the conversation.
reasoning: Option<Reasoning>Reasoning configuration used.
status: StringThe status of the response generation (completed, failed, in_progress, incomplete).
stream: Option<bool>Whether to stream the response. Defaults to false.
temperature: Option<f32>Sampling temperature.
text: Option<TextResponseFormatConfigurationOptions>Text response format configuration.
tool_choice: Option<ToolChoice>Tool choice strategy used.
tools: Option<Vec<Tool>>Tools available to the model.
top_p: Option<f32>Nucleus sampling probability.
truncation: Option<String>Truncation strategy (“auto” or “disabled”).
usage: Option<ResponseUsage>Usage statistics for the request. Null if status is not completed.
user: Option<String>End-user identifier.
Implementations
Sourceimpl ResponseObject
impl ResponseObject
Sourcepub fn former() -> ResponseObjectFormer<ResponseObjectFormerDefinition<(), ResponseObject, ReturnPreformed>>
pub fn former() -> ResponseObjectFormer<ResponseObjectFormerDefinition<(), ResponseObject, ReturnPreformed>>
Provides a mechanism to initiate the formation process with a default completion behavior.