Module session

Module session 

Session configuration and management structures for the Realtime API.

Modules

exposed
Exposed namespace of the module.
orphan
Orphan namespace of the module.
own
Own namespace of the module.
prelude
Prelude to use essentials: use my_module ::prelude :: *.

Structs

RealtimeClientSecret
Represents an ephemeral client secret for authenticating Realtime API connections.
RealtimeSession
Represents the configuration of an active Realtime session.
RealtimeSessionCreateRequest
Represents the request body for creating or updating a Realtime session via REST or WebSocket.
RealtimeSessionCreateResponse
Response object returned when creating a Realtime session via REST API.
RealtimeSessionInputAudioNoiseReduction
Configuration for input audio noise reduction.
RealtimeSessionInputAudioTranscription
Configuration for input audio transcription in a Realtime session.
RealtimeSessionTurnDetection
Configuration for turn detection (VAD) in a Realtime session.