Structures related to API Usage and Costs endpoints.
Modules
- exposed
- Exposed namespace of the module.
- orphan
- Orphan namespace of the module.
- own
- Own namespace of the module.
- prelude
- Prelude to use essentials:
use my_module ::prelude :: *.
Structs
- Costs
Result - Represents the aggregated cost details for a specific time bucket and grouping.
- Costs
Result Amount - Represents the monetary value and currency for a cost item.
- Usage
Audio Speeches Result - Represents aggregated usage details for the Audio Speeches API within a time bucket.
- Usage
Audio Transcriptions Result - Represents aggregated usage details for the Audio Transcriptions API within a time bucket.
- Usage
Code Interpreter Sessions Result - Represents aggregated usage details for Code Interpreter sessions within a time bucket.
- Usage
Completions Result - Represents aggregated usage details for the Completions API within a time bucket.
- Usage
Embeddings Result - Represents aggregated usage details for the Embeddings API within a time bucket.
- Usage
Images Result - Represents aggregated usage details for the Images API within a time bucket.
- Usage
Moderations Result - Represents aggregated usage details for the Moderations API within a time bucket.
- Usage
Response - Represents the paginated response from a Usage or Costs API endpoint.
- Usage
Time Bucket - Represents a time bucket containing aggregated usage or cost results.
- Usage
Vector Stores Result - Represents aggregated usage details for Vector Stores within a time bucket.
Enums
- Usage
Result - Represents the aggregated usage or cost result within a time bucket, varying by endpoint.