DynamicConfigManager

Struct DynamicConfigManager 

pub struct DynamicConfigManager;
Utilities for dynamic configuration management

Implementations

Source

impl DynamicConfigManager

pub fn create_change_watcher() -> (ConfigChangeSender, ConfigChangeReceiver)

Create a configuration change watcher

pub fn create_value_watcher<T: Clone + Send + 'static>( initial_value: T, ) -> (Sender<T>, Receiver<T>)

Create a configuration value watcher

pub fn apply_atomic_changes( manager: &ConfigManager, changes: Vec<(String, ConfigValue)>, ) -> Result<ConfigSnapshot, Vec<String>>

Apply configuration changes atomically

Errors

Returns an error if the updated configuration fails validation.

pub fn create_backup(snapshot: &ConfigSnapshot) -> String

Create a configuration backup

pub fn restore_from_backup(backup: &str) -> Result<ConfigSnapshot, String>

Restore configuration from backup

Errors

Returns an error if the backup cannot be parsed as a valid configuration snapshot.

pub fn merge_snapshots( base: &ConfigSnapshot, overlay: ConfigSnapshot, ) -> ConfigSnapshot

Merge two configuration snapshots