pub struct RealtimeServerEventInputAudioBufferCommitted {
pub event_id: String,
pub previous_item_id: Option<String>,
pub item_id: String,
}Expand description
Fields
event_id: StringThe unique ID of the server event.
previous_item_id: Option<String>The ID of the preceding item after which the new item will be inserted.
item_id: StringThe ID of the user message item that will be created.