EnhancedRetryConfig

Struct EnhancedRetryConfig 

pub struct EnhancedRetryConfig {
    pub max_attempts: u32,
    pub base_delay_ms: u64,
    pub max_delay_ms: u64,
    pub max_elapsed_time_ms: u64,
    pub jitter_ms: u64,
    pub backoff_multiplier: f64,
}
Enhanced retry configuration for HTTP requests

Fields

max_attempts: u32

Maximum number of retry attempts

base_delay_ms: u64

Base delay in milliseconds between retries

max_delay_ms: u64

Maximum delay in milliseconds between retries

max_elapsed_time_ms: u64

Maximum elapsed time for all retry attempts in milliseconds

jitter_ms: u64

Jitter amount in milliseconds to add randomness

backoff_multiplier: f64

Multiplier for exponential backoff (default : 2.0)

Implementations

Source

impl EnhancedRetryConfig

pub fn new() -> Self

Create a new retry configuration

pub fn with_max_attempts(self, max_attempts: u32) -> Self

Set maximum retry attempts

pub fn with_base_delay(self, base_delay_ms: u64) -> Self

Set base delay between retries

pub fn with_max_delay(self, max_delay_ms: u64) -> Self

Set maximum delay between retries

pub fn with_max_elapsed_time(self, max_elapsed_time_ms: u64) -> Self

Set maximum elapsed time for all attempts

pub fn with_jitter(self, jitter_ms: u64) -> Self

Set jitter amount for randomization

pub fn with_backoff_multiplier(self, multiplier: f64) -> Self

Set backoff multiplier for exponential backoff

pub fn calculate_delay(&self, attempt: u32) -> Duration

Calculate retry delay with exponential backoff and jitter Formula : base_delay * backoff_multiplier^attempt + random(0, jitter_ms)

pub fn is_retryable_error(&self, error: &OpenAIError) -> bool

Check if an error is retryable

pub fn validate(&self) -> Result<(), String>

Validate configuration parameters

Errors

Returns an error if any configuration parameter is invalid (e.g., zero values where positive values are required).