#[non_exhaustive]pub enum ComputerAction {
Click {
button: String,
x: i64,
y: i64,
},
DoubleClick {
x: i64,
y: i64,
},
Drag {
path: Vec<Coordinate>,
},
KeyPress {
keys: Vec<String>,
},
Move {
x: i64,
y: i64,
},
Screenshot {},
Scroll {
x: i64,
y: i64,
scroll_x: i64,
scroll_y: i64,
},
Type {
text: String,
},
Wait {},
}Expand description
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Click
A click action.
Fields
Which mouse button was pressed (left, right, wheel, back, forward).
DoubleClick
A double click action.
Fields
Drag
A drag action.
Fields

path: Vec<Coordinate>An array of coordinates representing the path of the drag action.
KeyPress
A collection of keypresses the model would like to perform.
Move
A mouse move action.
Screenshot
A screenshot action.
Scroll
A scroll action.
Fields
Type
An action to type in text.
Wait
A wait action.