ComputerAction

Enum ComputerAction 

#[non_exhaustive]
pub enum ComputerAction { Click { button: String, x: i64, y: i64, }, DoubleClick { x: i64, y: i64, }, Drag { path: Vec<Coordinate>, }, KeyPress { keys: Vec<String>, }, Move { x: i64, y: i64, }, Screenshot {}, Scroll { x: i64, y: i64, scroll_x: i64, scroll_y: i64, }, Type { text: String, }, Wait {}, }
Represents different actions the computer use tool can perform.

Used By

  • ComputerToolCall

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Click

A click action.

Fields

button: String

Which mouse button was pressed (left, right, wheel, back, forward).

x: i64

The x-coordinate where the click occurred.

y: i64

The y-coordinate where the click occurred.



DoubleClick

A double click action.

Fields

x: i64

The x-coordinate where the double click occurred.

y: i64

The y-coordinate where the double click occurred.



Drag

A drag action.

Fields

path: Vec<Coordinate>

An array of coordinates representing the path of the drag action.



KeyPress

A collection of keypresses the model would like to perform.

Fields

keys: Vec<String>

The combination of keys the model is requesting to be pressed.



Move

A mouse move action.

Fields

x: i64

The x-coordinate to move to.

y: i64

The y-coordinate to move to.



Screenshot

A screenshot action.



Scroll

A scroll action.

Fields

x: i64

The x-coordinate where the scroll occurred.

y: i64

The y-coordinate where the scroll occurred.

scroll_x: i64

The horizontal scroll distance.

scroll_y: i64

The vertical scroll distance.



Type

An action to type in text.

Fields

text: String

The text to type.



Wait

A wait action.