pub struct WebSocketEventSender { /* private fields */ }Expand description
Sender for WebSocket events
Implementations
Sourceimpl WebSocketEventSender
impl WebSocketEventSender
Sourcepub fn send_event(&self, event: WebSocketEvent) -> Result<(), &'static str>
pub fn send_event(&self, event: WebSocketEvent) -> Result<(), &'static str>
Send a WebSocket event
Errors
Returns an error if the event cannot be sent through the WebSocket event channel.
Sourcepub fn send_connected(&self, connection_id: String) -> Result<(), &'static str>
pub fn send_connected(&self, connection_id: String) -> Result<(), &'static str>
Send connection established event
Errors
Returns an error if the connection event cannot be sent through the WebSocket event channel.
Sourcepub fn send_disconnected(
&self,
connection_id: String,
reason: Option<String>,
) -> Result<(), &'static str>
pub fn send_disconnected( &self, connection_id: String, reason: Option<String>, ) -> Result<(), &'static str>
Send disconnection event
Errors
Returns an error if the disconnection event cannot be sent through the WebSocket event channel.
Sourcepub fn send_message_received(
&self,
connection_id: String,
message: WebSocketMessage,
) -> Result<(), &'static str>
pub fn send_message_received( &self, connection_id: String, message: WebSocketMessage, ) -> Result<(), &'static str>
Send message received event
Errors
Returns an error if the message received event cannot be sent through the WebSocket event channel.