Batch

Struct Batch 

pub struct Batch {
Show 20 fields pub id: String, pub object: String, pub endpoint: String, pub errors: Option<BatchErrors>, pub input_file_id: String, pub completion_window: String, pub status: String, pub output_file_id: Option<String>, pub error_file_id: Option<String>, pub created_at: i64, pub in_progress_at: Option<i64>, pub expires_at: Option<i64>, pub finalizing_at: Option<i64>, pub completed_at: Option<i64>, pub failed_at: Option<i64>, pub expired_at: Option<i64>, pub cancelling_at: Option<i64>, pub cancelled_at: Option<i64>, pub request_counts: Option<BatchRequestCounts>, pub metadata: Option<Metadata>,
}
Represents a Batch job object.

Used By

  • /batches (POST response, GET - in ListBatchesResponse)
  • /batches/{batch_id} (GET)
  • /batches/{batch_id}/cancel (POST response)

Fields

id: String

Batch job ID.

object: String

The object type, always batch.

endpoint: String

The OpenAI API endpoint used by the batch.

errors: Option<BatchErrors>

Errors associated with the batch job.

input_file_id: String

The ID of the input file for the batch.

completion_window: String

The time frame within which the batch should be processed (e.g., “24h”).

status: String

The current status of the batch.

output_file_id: Option<String>

The ID of the file containing the outputs of successfully executed requests.

error_file_id: Option<String>

The ID of the file containing the outputs of requests with errors.

created_at: i64

Creation timestamp.

in_progress_at: Option<i64>

Timestamp when processing started.

expires_at: Option<i64>

Expiration timestamp.

finalizing_at: Option<i64>

Timestamp when finalization started.

completed_at: Option<i64>

Completion timestamp.

failed_at: Option<i64>

Failure timestamp.

expired_at: Option<i64>

Timestamp when the batch expired.

cancelling_at: Option<i64>

Timestamp when cancellation started.

cancelled_at: Option<i64>

Timestamp when the batch was cancelled.

request_counts: Option<BatchRequestCounts>

Request counts for different statuses within the batch.

metadata: Option<Metadata>

Metadata associated with the batch.