pub struct ProjectServiceAccountListResponse {
pub object: String,
pub data: Vec<ProjectServiceAccount>,
pub first_id: Option<String>,
pub last_id: Option<String>,
pub has_more: bool,
}Expand description
Response containing a list of project service accounts.
Used By
/organization/projects/{project_id}/service_accounts(GET)
Fields
object: StringObject type, always “list”.
data: Vec<ProjectServiceAccount>List of Project Service Account objects.
first_id: Option<String>ID of the first service account in the list.
last_id: Option<String>ID of the last service account in the list.
has_more: boolIndicates if more service accounts are available.