pub struct MessageDeltaContentTextAnnotationsFilePathObject {
pub index: i32,
pub type: String,
pub text: Option<String>,
pub file_path: Option<FilePathAnnotation>,
pub start_index: Option<i32>,
pub end_index: Option<i32>,
}Expand description
Fields
index: i32The index of the annotation in the text content part.
type: StringAlways file_path.
text: Option<String>The text in the message content that needs to be replaced.
file_path: Option<FilePathAnnotation>Details of the file path.
start_index: Option<i32>Start index of the file path in the text.
end_index: Option<i32>End index of the file path in the text.