pub struct MessageContentTextAnnotationsFileCitationObject {
pub type: String,
pub text: String,
pub file_citation: FileCitationAnnotation,
pub start_index: i32,
pub end_index: i32,
}Expand description
A citation within the message that points to a specific quote from a specific File.
Used By
Annotation::FileCitation(withinoutput.rs)
Fields
type: StringAlways file_citation.
text: StringThe text in the message content that needs to be replaced.
file_citation: FileCitationAnnotationDetails of the file citation.
start_index: i32Start index of the citation in the text.
end_index: i32End index of the citation in the text.