pub struct FineTunePreferenceInputData {
pub messages: Vec<ChatCompletionResponseMessage>,
pub tools: Option<Vec<ChatCompletionTool>>,
pub parallel_tool_calls: Option<ParallelToolCalls>,
}Expand description
Contains the input messages and optional tools for a DPO preference example.
Used By
FineTunePreferenceRequestInput
Fields
messages: Vec<ChatCompletionResponseMessage>The list of messages forming the input context.
tools: Option<Vec<ChatCompletionTool>>Optional list of tools available for this example.
parallel_tool_calls: Option<ParallelToolCalls>Optional setting for parallel tool calls in this example.