pub struct RealtimeClientEventInputAudioBufferCommit {
pub event_id: Option<String>,
}Expand description
Client event to commit the input audio buffer (creates a user message). Not needed in Server VAD mode.
Used By
RealtimeClientEvent
Fields
event_id: Option<String>Optional client-generated ID for the event.
Implementations
Sourceimpl RealtimeClientEventInputAudioBufferCommit
impl RealtimeClientEventInputAudioBufferCommit
Sourcepub fn former() -> RealtimeClientEventInputAudioBufferCommitFormer<RealtimeClientEventInputAudioBufferCommitFormerDefinition<(), RealtimeClientEventInputAudioBufferCommit, ReturnPreformed>>
pub fn former() -> RealtimeClientEventInputAudioBufferCommitFormer<RealtimeClientEventInputAudioBufferCommitFormerDefinition<(), RealtimeClientEventInputAudioBufferCommit, ReturnPreformed>>
Provides a mechanism to initiate the formation process with a default completion behavior.