#[non_exhaustive]pub struct FunctionParameters(pub Value);Expand description
Represents the parameters for a function tool, described as a JSON Schema object.
See the guide for examples, and the
JSON Schema reference for
documentation about the format. Omitting parameters defines a function with an empty parameter list.
Used By
FunctionToolAssistantToolsFunction(withinassistants_shared.rs)ChatCompletionFunctions(withinchat_shared.rs)
Tuple Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.0: ValueImplementations