WebSearchTool

Struct WebSearchTool 

#[non_exhaustive]
pub struct WebSearchTool { pub search_context_size: Option<String>, pub user_location: Option<WebSearchUserLocation>, }
Defines a web search tool. This tool searches the web for relevant results to use in a response. Learn more about the web search tool.

Used By

  • Tool::WebSearch (within tools.rs)

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
search_context_size: Option<String>

The amount of context window space to use for search results

user_location: Option<WebSearchUserLocation>

User location information for search personalization

Implementations

Source

impl WebSearchTool

pub fn former() -> WebSearchToolFormer<WebSearchToolFormerDefinition<(), WebSearchTool, ReturnPreformed>>

Provides a mechanism to initiate the formation process with a default completion behavior.