Session configuration and management structures for the Realtime API.
Modules
- exposed
- Exposed namespace of the module.
- orphan
- Orphan namespace of the module.
- own
- Own namespace of the module.
- prelude
- Prelude to use essentials:
use my_module ::prelude :: *.
Structs
- Realtime
Client Secret - Represents an ephemeral client secret for authenticating Realtime API connections.
- Realtime
Session - Represents the configuration of an active Realtime session.
- Realtime
Session Create Request - Represents the request body for creating or updating a Realtime session via REST or WebSocket.
- Realtime
Session Create Response - Response object returned when creating a Realtime session via REST API.
- Realtime
Session Input Audio Noise Reduction - Configuration for input audio noise reduction.
- Realtime
Session Input Audio Transcription - Configuration for input audio transcription in a Realtime session.
- Realtime
Session Turn Detection - Configuration for turn detection (VAD) in a Realtime session.