pub struct RealtimeSessionCreateRequest {Show 13 fields
pub modalities: Option<Vec<String>>,
pub model: Option<String>,
pub instructions: Option<String>,
pub voice: Option<VoiceIdsShared>,
pub input_audio_format: Option<String>,
pub output_audio_format: Option<String>,
pub input_audio_transcription: Option<RealtimeSessionInputAudioTranscription>,
pub turn_detection: Option<RealtimeSessionTurnDetection>,
pub input_audio_noise_reduction: Option<RealtimeSessionInputAudioNoiseReduction>,
pub tools: Option<Vec<Tool>>,
pub tool_choice: Option<String>,
pub temperature: Option<f64>,
pub max_response_output_tokens: Option<Value>,
}Expand description
Represents the request body for creating or updating a Realtime session via REST or WebSocket.
Used By
/realtime/sessions(POST)RealtimeClientEventSessionUpdate
Fields
modalities: Option<Vec<String>>The set of modalities the model can respond with.
model: Option<String>The Realtime model ID.
instructions: Option<String>Default system instructions.
voice: Option<VoiceIdsShared>Default voice for audio output.
input_audio_format: Option<String>Format of input audio.
output_audio_format: Option<String>Format of output audio.
input_audio_transcription: Option<RealtimeSessionInputAudioTranscription>Input audio transcription configuration.
turn_detection: Option<RealtimeSessionTurnDetection>Turn detection configuration.
input_audio_noise_reduction: Option<RealtimeSessionInputAudioNoiseReduction>Input audio noise reduction configuration.
tools: Option<Vec<Tool>>Default tools available to the model.
tool_choice: Option<String>Default tool choice strategy.
temperature: Option<f64>Default sampling temperature.
max_response_output_tokens: Option<Value>Default maximum output tokens.
Implementations
Sourceimpl RealtimeSessionCreateRequest
impl RealtimeSessionCreateRequest
Sourcepub fn former() -> RealtimeSessionCreateRequestFormer<RealtimeSessionCreateRequestFormerDefinition<(), RealtimeSessionCreateRequest, ReturnPreformed>>
pub fn former() -> RealtimeSessionCreateRequestFormer<RealtimeSessionCreateRequestFormerDefinition<(), RealtimeSessionCreateRequest, ReturnPreformed>>
Provides a mechanism to initiate the formation process with a default completion behavior.