Annotation

Enum Annotation 

pub enum Annotation {
    FileCitation {
        text: String,
        file_citation: FileCitationAnnotation,
        start_index: u32,
        end_index: u32,
    },
    UrlCitation {
        url: String,
        title: String,
        start_index: u32,
        end_index: u32,
    },
    FilePath {
        text: String,
        file_path: FilePathAnnotation,
        start_index: u32,
        end_index: u32,
    },
}
Represents annotations embedded within output text content. These annotations provide context or references for parts of the text.

Used By

  • OutputContentPart::Text
  • MessageContentTextObject (within assistants_shared.rs)
  • MessageDeltaTextContent (within assistants_shared.rs)
  • ResponseTextAnnotationDeltaEvent (within realtime_shared.rs)

Variants



FileCitation

A citation within the message that points to a specific quote from a specific File.

Fields

text: String

The text in the message content that needs to be replaced.

file_citation: FileCitationAnnotation

The details of the file citation.

start_index: u32

The start index of the citation in the text.

end_index: u32

The end index of the citation in the text.



UrlCitation

A citation for a web resource used to generate a model response.

Fields

url: String

The URL of the web resource.

title: String

The title of the web resource.

start_index: u32

The start index of the citation in the text.

end_index: u32

The end index of the citation in the text.



FilePath

A URL for the file that’s generated when the assistant used the code_interpreter tool.

Fields

text: String

The text in the message content that needs to be replaced.

file_path: FilePathAnnotation

The details of the file path.

start_index: u32

The start index of the file path in the text.

end_index: u32

The end index of the file path in the text.