#[non_exhaustive]pub struct ResponseContentPartAddedEvent {
pub content_index: u32,
pub item_id: String,
pub output_index: u32,
pub part: OutputContentPart,
}Expand description
Event data for response.content_part.added.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.content_index: u32The index of the content part that was added.
item_id: StringThe ID of the output item that the content part was added to.
output_index: u32The index of the output item that the content part was added to.
part: OutputContentPartThe content part that was added.