Module usage_shared

Module usage_shared 

Structures related to API Usage and Costs endpoints.

Modules

exposed
Exposed namespace of the module.
orphan
Orphan namespace of the module.
own
Own namespace of the module.
prelude
Prelude to use essentials: use my_module ::prelude :: *.

Structs

CostsResult
Represents the aggregated cost details for a specific time bucket and grouping.
CostsResultAmount
Represents the monetary value and currency for a cost item.
UsageAudioSpeechesResult
Represents aggregated usage details for the Audio Speeches API within a time bucket.
UsageAudioTranscriptionsResult
Represents aggregated usage details for the Audio Transcriptions API within a time bucket.
UsageCodeInterpreterSessionsResult
Represents aggregated usage details for Code Interpreter sessions within a time bucket.
UsageCompletionsResult
Represents aggregated usage details for the Completions API within a time bucket.
UsageEmbeddingsResult
Represents aggregated usage details for the Embeddings API within a time bucket.
UsageImagesResult
Represents aggregated usage details for the Images API within a time bucket.
UsageModerationsResult
Represents aggregated usage details for the Moderations API within a time bucket.
UsageResponse
Represents the paginated response from a Usage or Costs API endpoint.
UsageTimeBucket
Represents a time bucket containing aggregated usage or cost results.
UsageVectorStoresResult
Represents aggregated usage details for Vector Stores within a time bucket.

Enums

UsageResult
Represents the aggregated usage or cost result within a time bucket, varying by endpoint.