pub struct HostConnectionPool {
pub host: String,
pub available: Arc<Mutex<VecDeque<Arc<ManagedConnection>>>>,
pub in_use: Arc<RwLock<HashMap<String, Arc<ManagedConnection>>>>,
pub config: ConnectionConfig,
pub pool_stats: Arc<RwLock<PoolStats>>,
}Expand description
Connection pool manager for a specific host
Fields
host: StringHost this pool manages
available: Arc<Mutex<VecDeque<Arc<ManagedConnection>>>>Available connections
in_use: Arc<RwLock<HashMap<String, Arc<ManagedConnection>>>>Currently in-use connections
config: ConnectionConfigPool configuration
pool_stats: Arc<RwLock<PoolStats>>Pool-level statistics
Implementations
Sourceimpl HostConnectionPool
impl HostConnectionPool
Sourcepub fn new(host: String, config: ConnectionConfig) -> Self
pub fn new(host: String, config: ConnectionConfig) -> Self
Create new connection pool for host
Sourcepub async fn get_connection(&self) -> Result<Arc<ManagedConnection>, Error>
pub async fn get_connection(&self) -> Result<Arc<ManagedConnection>, Error>
Get a connection from the pool or create a new one
Errors
Returns an error if a new connection cannot be created when the pool is empty or when all existing connections are unhealthy.
Sourcepub async fn return_connection(&self, conn: Arc<ManagedConnection>)
pub async fn return_connection(&self, conn: Arc<ManagedConnection>)
Return connection to available pool
Sourcepub async fn cleanup_connections(&self)
pub async fn cleanup_connections(&self)
Cleanup idle and unhealthy connections
Sourcepub async fn get_stats(&self) -> PoolStatistics
pub async fn get_stats(&self) -> PoolStatistics
Get pool statistics