pub struct ConfigManager { /* private fields */ }Expand description
Configuration manager for stateless configuration operations
Implementations
Sourceimpl ConfigManager
impl ConfigManager
Sourcepub fn new(validator: ConfigValidator) -> Self
pub fn new(validator: ConfigValidator) -> Self
Create a new configuration manager
Sourcepub fn get_snapshot(&self) -> ConfigSnapshot
pub fn get_snapshot(&self) -> ConfigSnapshot
Sourcepub fn update_snapshot(
&self,
new_snapshot: ConfigSnapshot,
) -> Result<ConfigSnapshot, Vec<String>>
pub fn update_snapshot( &self, new_snapshot: ConfigSnapshot, ) -> Result<ConfigSnapshot, Vec<String>>
Sourcepub fn update_value(
&self,
key: String,
value: ConfigValue,
) -> Result<ConfigSnapshot, Vec<String>>
pub fn update_value( &self, key: String, value: ConfigValue, ) -> Result<ConfigSnapshot, Vec<String>>
Update a single configuration value
Errors
Returns an error if the updated configuration fails validation.
Sourcepub fn remove_value(&self, key: &str) -> Result<ConfigSnapshot, Vec<String>>
pub fn remove_value(&self, key: &str) -> Result<ConfigSnapshot, Vec<String>>
Remove a configuration value
Errors
Returns an error if the updated configuration fails validation.
Sourcepub fn get_value(&self, key: &str) -> Option<ConfigValue>
pub fn get_value(&self, key: &str) -> Option<ConfigValue>
Get a specific configuration value