pub struct FailoverEventSender { /* private fields */ }Expand description
Sender for failover events
Implementations
Sourceimpl FailoverEventSender
impl FailoverEventSender
Sourcepub fn send_event(&self, event: FailoverEvent) -> Result<(), &'static str>
pub fn send_event(&self, event: FailoverEvent) -> Result<(), &'static str>
Send a failover event
Errors
Returns an error if the event channel is closed or the receiver has been dropped.
Sourcepub fn send_health_change(
&self,
endpoint_id: String,
old_health: EndpointHealth,
new_health: EndpointHealth,
) -> Result<(), &'static str>
pub fn send_health_change( &self, endpoint_id: String, old_health: EndpointHealth, new_health: EndpointHealth, ) -> Result<(), &'static str>
Send health change event
Errors
Returns an error if the event cannot be sent due to channel closure or receiver unavailability.