pub struct FineTuningJobCheckpointMetrics {
pub step: Option<f64>,
pub train_loss: Option<f64>,
pub train_mean_token_accuracy: Option<f64>,
pub valid_loss: Option<f64>,
pub valid_mean_token_accuracy: Option<f64>,
pub full_valid_loss: Option<f64>,
pub full_valid_mean_token_accuracy: Option<f64>,
}Expand description
Metrics reported at a specific step number during a fine-tuning job.
Used By
FineTuningJobCheckpoint
Fields
step: Option<f64>The step number associated with these metrics.
train_loss: Option<f64>Training loss at this step.
train_mean_token_accuracy: Option<f64>Mean token accuracy on the training data at this step.
valid_loss: Option<f64>Validation loss at this step.
valid_mean_token_accuracy: Option<f64>Mean token accuracy on the validation data at this step.
full_valid_loss: Option<f64>Full validation loss computed at the end of the job.
full_valid_mean_token_accuracy: Option<f64>Full mean token accuracy on the validation data computed at the end of the job.