DeploymentManager

Struct DeploymentManager 

pub struct DeploymentManager { /* private fields */ }
Deployment manager for orchestrating model deployments

Implementations

Source

impl DeploymentManager

pub fn new(config: DeploymentManagerConfig) -> Self

Create a new deployment manager

pub fn add_deployment( &mut self, deployment: ModelDeployment, ) -> Result<(), String>

Add a deployment to the manager

Errors

Returns an error if the maximum number of deployments is reached or if a deployment with the same name already exists.

pub fn get_deployment(&self, name: &str) -> Option<&ModelDeployment>

Get a deployment by name

pub fn get_deployment_mut(&mut self, name: &str) -> Option<&mut ModelDeployment>

Get a mutable deployment by name

pub fn remove_deployment(&mut self, name: &str) -> Option<ModelDeployment>

Remove a deployment

pub fn deployment_names(&self) -> Vec<String>

List all deployment names

pub fn deployment_stats(&self) -> DeploymentStats

Get deployment statistics

pub fn cleanup_history(&mut self)

Cleanup old deployment history