Realtime

Struct Realtime 

pub struct Realtime<'client, E>{ /* private fields */ }
The client for the OpenAI Realtime API.

Implementations

Source

impl<'client, E> Realtime<'client, E>

pub async fn create_session( &self, request: RealtimeSessionCreateRequest, ) -> Result<RealtimeSessionCreateResponse>

Creates a new Realtime session.

Arguments
  • request: The request body for creating a Realtime session.
Errors

Returns OpenAIError if the request fails.

pub async fn retrieve_session( &self, session_id: &str, ) -> Result<RealtimeSession>

Retrieves a Realtime session.

Arguments
  • session_id: The ID of the Realtime session to retrieve.
Errors

Returns OpenAIError if the request fails.

pub async fn update_session( &self, session_id: &str, request: Value, ) -> Result<RealtimeSession>

Updates a Realtime session.

Arguments
  • session_id: The ID of the Realtime session to update.
  • request: The request body for updating the Realtime session.
Errors

Returns OpenAIError if the request fails.

pub async fn delete_session(&self, session_id: &str) -> Result<Value>

Deletes a Realtime session.

Arguments
  • session_id: The ID of the Realtime session to delete.
Errors

Returns OpenAIError if the request fails.

pub async fn create_transcription_session( &self, request: RealtimeTranscriptionSessionCreateRequest, ) -> Result<RealtimeTranscriptionSessionCreateResponse>

Creates a new Realtime transcription session.

Arguments
  • request: The request body for creating a Realtime transcription session.
Errors

Returns OpenAIError if the request fails.

pub async fn update_transcription_session( &self, session_id: &str, request: Value, ) -> Result<RealtimeTranscriptionSessionCreateResponse>

Updates a Realtime transcription session.

Arguments
  • session_id: The ID of the Realtime transcription session to update.
  • request: The request body for updating the Realtime transcription session.
Errors

Returns OpenAIError if the request fails.

pub async fn delete_transcription_session( &self, session_id: &str, ) -> Result<Value>

Deletes a Realtime transcription session.

Arguments
  • session_id: The ID of the Realtime transcription session to delete.
Errors

Returns OpenAIError if the request fails.

pub async fn connect_ws(&self, session_id: &str) -> Result<WsSession>

Establishes a WebSocket connection for Realtime API events.

Arguments
  • session_id: The ID of the Realtime session to connect to.
Errors

Returns OpenAIError::Ws if the WebSocket connection fails.