pub struct RealtimeServerEventConversationItemTruncated {
pub event_id: String,
pub item_id: String,
pub content_index: i32,
pub audio_end_ms: i32,
}Expand description
Fields
event_id: StringThe unique ID of the server event.
item_id: StringThe ID of the assistant message item that was truncated.
content_index: i32The index of the content part that was truncated.
audio_end_ms: i32The duration up to which the audio was truncated (ms).