pub struct RealtimeServerEventResponseOutputItemDone {
pub event_id: String,
pub response_id: String,
pub output_index: i32,
pub item: RealtimeConversationItem,
}Expand description
Fields
event_id: StringThe unique ID of the server event.
response_id: StringThe ID of the Response to which the item belongs.
output_index: i32The index of the output item in the Response.
item: RealtimeConversationItemThe output item that was marked done.