VectorStoreObject

Struct VectorStoreObject 

#[non_exhaustive]
pub struct VectorStoreObject { pub created_at: i64, pub expires_after: Option<VectorStoreExpirationAfter>, pub expires_at: Option<i64>, pub file_counts: VectorStoreFileCounts, pub id: String, pub last_active_at: Option<i64>, pub metadata: Option<Metadata>, pub name: Option<String>, pub object: String, pub status: String, pub usage_bytes: i64, }
Represents a vector store object. A vector store is a collection of processed files can be used by the file_search tool.

Used By

  • /vector_stores (GET - in ListVectorStoresResponse, POST response)
  • /vector_stores/{vector_store_id} (GET, POST response)
  • ListVectorStoresResponse

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
created_at: i64

The Unix timestamp (in seconds) for when the vector store was created.

expires_after: Option<VectorStoreExpirationAfter>

The expiration policy for the vector store.

expires_at: Option<i64>

The Unix timestamp (in seconds) for when the vector store will expire.

file_counts: VectorStoreFileCounts

Counts of files in different statuses within the vector store.

id: String

The identifier, which can be referenced in API endpoints.

last_active_at: Option<i64>

The Unix timestamp (in seconds) for when the vector store was last active.

metadata: Option<Metadata>

Set of 16 key-value pairs attached to the object.

name: Option<String>

The name of the vector store.

object: String

The object type, which is always vector_store.

status: String

The status of the vector store (expired, in_progress, or completed).

usage_bytes: i64

The total number of bytes used by the files in the vector store.