pub async fn create_failover_client() -> Result<Client<OpenaiEnvironmentImpl>>Expand description
Convenience function : Create failover client using global manager
Errors
Returns an error if the global authentication manager is not initialized, mutex is poisoned, or failover client creation fails.