Orphan namespace of the module.
Structs
- Computer
Tool - Defines the computer use tool. A tool that controls a virtual computer. Learn more about the computer tool.
- Computer
Tool Call - Represents a call to the computer use tool. See the computer use guide for more information.
- Computer
Tool Call Output - Represents the output returned from a computer tool call action.
- Computer
Tool Call Safety Check - Represents a safety check associated with a computer tool call.
- File
Search Ranking Options - Represents ranking options for file search results.
- File
Search Tool - Defines a file search tool.
- File
Search Tool Call - Represents a call to the file search tool, including queries and results.
- Function
Parameters - Represents the parameters for a function tool, described as a JSON Schema object.
See the guide for examples, and the
JSON Schema reference for
documentation about the format. Omitting
parametersdefines a function with an empty parameter list. - Function
Tool - Defines a function tool that the model can call.
- Function
Tool Call - Represents a call to a function tool, generated by the model.
- Function
Tool Call Output - Represents the output returned from a function tool call, to be sent back to the model.
- Tool
Choice Function - Specifies a function name for the
ToolChoice::Functionvariant. - WebSearch
Context Size - Represents web search context size options. High level guidance for the amount of context window space to use for the search.
- WebSearch
Location - Represents approximate location parameters for the web search.
- WebSearch
Tool - Defines a web search tool. This tool searches the web for relevant results to use in a response. Learn more about the web search tool.
- WebSearch
Tool Call - Represents a call to the web search tool. The results of a web search tool call. See the web search guide for more information.
- WebSearch
User Location - User location information for web search personalization
Enums
- Computer
Action - Represents different actions the computer use tool can perform.
- Tool
- Represents the available tools that can be used by models or assistants.
- Tool
Choice - Represents the choice of which tool the model should use.