Structures related to Vector Stores, including files, batches, and search results.
Modules
- exposed
- Exposed namespace of the module.
- orphan
- Orphan namespace of the module.
- own
- Own namespace of the module.
- prelude
- Prelude to use essentials:
use my_module ::prelude :: *.
Structs
- Auto
Chunking Strategy Request Param - Represents the auto chunking strategy parameter for requests.
- Comparison
Filter - Represents a filter comparing an attribute key to a value.
- Compound
Filter - Represents a filter combining multiple filters using
andoror. - List
Vector Store Files Response - Response containing a list of vector store files.
- List
Vector Stores Response - Response containing a list of vector stores.
- Other
Chunking Strategy Response Param - Represents an unknown or older chunking strategy in responses.
- Static
Chunking Strategy - Represents the static chunking strategy configuration.
- Static
Chunking Strategy Request Param - Represents the static chunking strategy parameter for requests.
- Static
Chunking Strategy Response Param - Represents the static chunking strategy as returned in responses.
- Vector
Store Expiration After - Represents the expiration policy for a vector store.
- Vector
Store File Batch Object - Represents a batch operation for adding files to a vector store.
- Vector
Store File Content Response - Represents the response containing the parsed content of a vector store file.
- Vector
Store File Counts - Represents the counts of files in different statuses within a vector store or batch.
- Vector
Store File Object - Represents a file attached to a vector store.
- Vector
Store Object - Represents a vector store object.
A vector store is a collection of processed files can be used by the
file_searchtool. - Vector
Store Search Result Content Object - Represents the content of a search result chunk.
- Vector
Store Search Result Item - Represents a single search result item from a vector store search.
- Vector
Store Search Results Page - Represents a paginated response from a vector store search.
Enums
- Chunking
Strategy Request Param - Represents the chunking strategy parameter for requests (auto or static).
- Chunking
Strategy Response - Represents the chunking strategy used for a file in a vector store (response format).
- Filter
- Represents a filter used in vector store search requests.