pub struct DiagnosticsCollector {
pub config: DiagnosticsConfig,
/* private fields */
}Expand description
Main diagnostics collector
Fields
config: DiagnosticsConfigConfiguration for diagnostics collection
Implementations
Sourceimpl DiagnosticsCollector
impl DiagnosticsCollector
Sourcepub fn new(config: DiagnosticsConfig) -> Self
pub fn new(config: DiagnosticsConfig) -> Self
Create a new diagnostics collector with the given configuration
Sourcepub fn record_request(&self, metrics: &RequestMetrics)
pub fn record_request(&self, metrics: &RequestMetrics)
Sourcepub fn record_response(&self, metrics: &ResponseMetrics)
pub fn record_response(&self, metrics: &ResponseMetrics)
Sourcepub fn record_error(&self, metrics: &ErrorMetrics)
pub fn record_error(&self, metrics: &ErrorMetrics)
Sourcepub fn get_request_count(&self) -> u64
pub fn get_request_count(&self) -> u64
Sourcepub fn get_error_count(&self) -> u64
pub fn get_error_count(&self) -> u64
Sourcepub fn get_metrics(&self) -> Vec<RequestResponseMetrics>
pub fn get_metrics(&self) -> Vec<RequestResponseMetrics>
Sourcepub fn get_error_metrics(&self) -> Vec<ErrorMetrics>
pub fn get_error_metrics(&self) -> Vec<ErrorMetrics>
Sourcepub fn get_performance_metrics(&self) -> PerformanceMetrics
pub fn get_performance_metrics(&self) -> PerformanceMetrics
Sourcepub fn generate_report(&self, time_range: Duration) -> DiagnosticsReport
pub fn generate_report(&self, time_range: Duration) -> DiagnosticsReport
Generate a comprehensive diagnostics report
Panics
Panics if the internal mutex is poisoned or if time arithmetic fails.
Sourcepub fn estimate_memory_usage(&self) -> usize
pub fn estimate_memory_usage(&self) -> usize
Estimate memory usage of the diagnostics collector
Panics
Panics if the internal mutex is poisoned.