Thread-related types and structures for the Assistants API.
Modules
- exposed
- Exposed namespace of the module.
- orphan
- Orphan namespace of the module.
- own
- Own namespace of the module.
- prelude
- Prelude to use essentials:
use my_module ::prelude :: *.
Structs
- List
Threads Response - Response containing a list of threads. (Note :
OpenAIspec doesn’t define a list threads endpoint, but this structure might be useful internally or for future expansion). - Thread
Object - Represents a thread that contains messages.