pub struct ReliableWebSocketSession { /* private fields */ }Expand description
Enhanced WebSocket session with reliability features
Implementations
Sourceimpl ReliableWebSocketSession
impl ReliableWebSocketSession
Sourcepub fn new(url: String, config: WebSocketReliabilityConfig) -> Self
pub fn new(url: String, config: WebSocketReliabilityConfig) -> Self
Create a new reliable WebSocket session
Sourcepub async fn connect_reliable(&self) -> Result<()>
pub async fn connect_reliable(&self) -> Result<()>
Sourcepub async fn send_event_reliable(
&self,
event: RealtimeClientEvent,
) -> Result<()>
pub async fn send_event_reliable( &self, event: RealtimeClientEvent, ) -> Result<()>
Sourcepub async fn recv_event_reliable(&self) -> Result<RealtimeServerEvent>
pub async fn recv_event_reliable(&self) -> Result<RealtimeServerEvent>
Receive an event from the WebSocket
Errors
Returns an error if no event can be received due to connection failures, WebSocket errors, or if no active connection exists.
Sourcepub async fn get_connection_state(&self) -> ConnectionState
pub async fn get_connection_state(&self) -> ConnectionState
Get current connection state
Sourcepub async fn is_connection_healthy(&self) -> bool
pub async fn is_connection_healthy(&self) -> bool
Check if connection is healthy
Panics
Panics if the internal mutex for last heartbeat tracking is poisoned.
Sourcepub async fn get_stats(&self) -> WebSocketConnectionStats
pub async fn get_stats(&self) -> WebSocketConnectionStats
Get connection statistics
Sourcepub fn get_buffered_message_count(&self) -> usize
pub fn get_buffered_message_count(&self) -> usize
Get buffered message count
Panics
This function will panic if the message buffer mutex is poisoned.
Sourcepub async fn flush_message_buffer(&self) -> Result<usize>
pub async fn flush_message_buffer(&self) -> Result<usize>