Structures related to model information.
Modules
- exposed
- Exposed namespace of the module.
- orphan
- Orphan namespace of the module.
- own
- Own namespace of the module.
- prelude
- Prelude to use essentials:
use my_module ::prelude :: *.
Structs
- Enhanced
List Models Response - Enhanced response containing a list of models with comprehensive metadata.
- Enhanced
Model - Enhanced model with comprehensive metadata including pricing and capabilities.
- List
Models Response - Response containing a list of available models.
- Model
- Describes an
OpenAImodel offering that can be used with the API. - Model
Capabilities - Model capabilities and technical specifications.
- Model
Comparison - Comparison between two models for analysis and decision-making.
- Model
Lifecycle - Model lifecycle and deprecation information.
- Model
Limitations - Model limitations and rate limits.
- Model
Pricing - Pricing information for a model.
- Response
Metadata - Metadata about the response containing aggregated model statistics.
Enums
- Model
Status - Enumeration of possible model statuses.