pub struct DynamicConfigManager;Expand description
Utilities for dynamic configuration management
Implementations
Sourceimpl DynamicConfigManager
impl DynamicConfigManager
Sourcepub fn create_change_watcher() -> (ConfigChangeSender, ConfigChangeReceiver)
pub fn create_change_watcher() -> (ConfigChangeSender, ConfigChangeReceiver)
Create a configuration change watcher
Sourcepub fn create_value_watcher<T: Clone + Send + 'static>(
initial_value: T,
) -> (Sender<T>, Receiver<T>)
pub fn create_value_watcher<T: Clone + Send + 'static>( initial_value: T, ) -> (Sender<T>, Receiver<T>)
Create a configuration value watcher
Sourcepub fn apply_atomic_changes(
manager: &ConfigManager,
changes: Vec<(String, ConfigValue)>,
) -> Result<ConfigSnapshot, Vec<String>>
pub fn apply_atomic_changes( manager: &ConfigManager, changes: Vec<(String, ConfigValue)>, ) -> Result<ConfigSnapshot, Vec<String>>
Apply configuration changes atomically
Errors
Returns an error if the updated configuration fails validation.
Sourcepub fn create_backup(snapshot: &ConfigSnapshot) -> String
pub fn create_backup(snapshot: &ConfigSnapshot) -> String
Create a configuration backup
Sourcepub fn restore_from_backup(backup: &str) -> Result<ConfigSnapshot, String>
pub fn restore_from_backup(backup: &str) -> Result<ConfigSnapshot, String>
Restore configuration from backup
Errors
Returns an error if the backup cannot be parsed as a valid configuration snapshot.
Sourcepub fn merge_snapshots(
base: &ConfigSnapshot,
overlay: ConfigSnapshot,
) -> ConfigSnapshot
pub fn merge_snapshots( base: &ConfigSnapshot, overlay: ConfigSnapshot, ) -> ConfigSnapshot
Merge two configuration snapshots