This module defines the error types for the OpenAI API client.
It includes a comprehensive OpenAIError enum that covers various
error scenarios, such as API errors, network issues, and serialization failures.
Modules
- exposed
- Exposed namespace of the module.
- orphan
- Orphan namespace of the module.
- own
- Own namespace of the module.
- prelude
- Prelude to use essentials:
use my_module ::prelude :: *.
Structs
- ApiError
- Represents an error returned by the
OpenAIAPI. Corresponds to theErrorschema in theOpenAPIspec. - ApiError
Wrap - A wrapper for
ApiErrorthat includes the HTTP status code.
Enums
- OpenAI
Error - Represents all possible errors that can occur when interacting with the
OpenAIAPI.
Functions
- map_
deserialization_ error - Helper function to map
serde_json::ErrortoOpenAIError::Internal.
Type Aliases
- Result
- Type alias for Results using
error_toolspattern