#[non_exhaustive]pub struct VectorStoreFileBatchObject {
pub created_at: i64,
pub file_counts: VectorStoreFileCounts,
pub id: String,
pub object: String,
pub status: String,
pub vector_store_id: String,
}Expand description
Represents a batch operation for adding files to a vector store.
Used By
/vector_stores/{vector_store_id}/file_batches(POST response)/vector_stores/{vector_store_id}/file_batches/{batch_id}(GET response)/vector_stores/{vector_store_id}/file_batches/{batch_id}/cancel(POST response)
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.created_at: i64The Unix timestamp (in seconds) for when the vector store files batch was created.
file_counts: VectorStoreFileCountsCounts of files in different statuses within the batch.
id: StringThe identifier, which can be referenced in API endpoints.
object: StringThe object type, which is always vector_store.file_batch.
status: StringThe status of the vector store files batch (in_progress, completed, cancelled or failed).
vector_store_id: StringThe ID of the vector store that the File is attached to.